/* taylor Version 2.1, May 26, 2023 */
/* Using coef lib: MY_FLOAT */
/* Using jet lib: jet_1. n symbol, degree 1 */
#include "taylor-bcp_sun_earth_jupiter.h"

/***********************************************************************
 *
 * Code generated by the TAYLOR translator.
 */

#define _N_DIM_ 6
#define _J_DIM_ 6


#define xInitUpJet InitUpJet
#define xInitJet InitJet
#define xNormJet NormJet
#define xMultiplyFloatJetA MultiplyFloatJetA
#define xAddJetJetA AddJetJetA 
#define xAssignJetToJet AssignJetToJet
#define xAssignJetToFloat AssignJetToFloat





/*
next line defines the largest power of 2 such that 2^(LEXP2) and
2^(-LEXP2) do not overflow/underflow the double arithmetic of your
computer.
*/
#define LEXP2 1023 

#define DEBUG_LEVEL 0 /* to print some internal information */

int taylor_step_auto(MY_FLOAT *ti,
                 MY_FLOAT *x,
                 int      dir,
                 int      step_ctl,
                 double   log10abserr,
                 double   log10relerr,
                 MY_FLOAT *endtime,
                 MY_FLOAT *ht,
                 int      *order,
                 MY_JET   *jetInOut)
/*
 * single integration step with taylor method. the parameters are:
 *
 * ti: on input:  time of the initial condition
 *     on output: new time
 *
 * x:  on input:  initial condition
 *     on output: new condition, corresponding to the (output) time ti
 *
 * dir: flag to integrate forward or backwards.
 *     1: forward
 *    -1: backwards
 *     WARNING: this flag is ignored if step_ctl (see below) is set to 0.
 *
 * step_ctl: flag for the step size control. the possible values are:
 *     0: no step size control, so the step and order are provided by
 *        the user. the parameter ht is used as step, and the parameter
 *        order (see below) is used as the order.
 *     1: standard stepsize control. it uses an approximation to the
 *        optimal order and to the radius of convergence of the series
 *        to approximate the 'optimal' step size. It tries to keep
 *        either the absolute or the relative errors below the given
 *        values. See the paper for more details.
 *     2: as 1, but adding an extra condition on the stepsize h: the
 *        terms of the series --after being multiplied by the suitable
 *        power of h-- cannot grow.
 *    -1: user defined stepsize control. the code has to be included
 *        in the routine compute_timestep_user_defined (you can find
 *        this routine below). The user should also provide code for
 *        the selection of degree (see the function
 *        compute_order_user_defined below).
 *
 * log10abserr: decimal log of the absolute accuracy. the routine
 *     tries to keep either the absolute or the relative errors below
 *     the given thresholds.
 *
 * log10relerr: decimal log of the relative accuracy. the routine
 *     tries to keep either the absolute or the relative errors below
 *     the given thresholds.
 *
 * endtime: if NULL, it is ignored. if step_ctl (see above) is set
 *     to 0, it is also ignored. otherwise, if the step size is too
 *     large, it is reduced so that the new time ti is exactly endtime
 *     (in that case, the function returns 1).
 *
 * ht: on input:  ignored/used as a time step (see parameter step_ctl)
 *     on output: time step used if the pointer is not NULL
 *
 * order: degree of the taylor expansion.
 *        input: this parameter is only used if step_ctl is 0,
 *               or if you add the code for the case step_ctl=3.
 *               its possible values are:
 *               < 2: the program will select degree 2 (if step_ctl is 0).
 *               >=2: the program will use this degree (if step_ctl is 0).
 *        ouput: degree used if the pointer is not NULL
 *
 * jetInOut: on input: the value of all declared jet variables
 *           on output: new value of the jet variable, corresponding to the new time
 *
 * return value:
 *  0: ok.
 *  1: ok, and ti=endtime.  
 * -1: not ok, unable to compute step size.  double_log  underflow/overflow  */
{
  MY_FLOAT **taylor_coefficients_auto(MY_FLOAT, MY_FLOAT*, int);
  MY_FLOAT **taylor_coefficients_autoA(MY_FLOAT, MY_FLOAT*, int, int);
  int compute_order_1_auto(double, double, double, int*);
  int comp_order_other_auto(double, double, double);
  double compute_stepsize_1_auto(MY_FLOAT**, MY_JET**, int, double, int);
  double compute_stepsize_2_auto(MY_FLOAT**, MY_JET**, int, double, int);
  double comp_stepsize_other_auto(MY_FLOAT**, MY_JET**, int, int, double, double, double);

  static MY_FLOAT **s,h,mtmp;
  static MY_JET jtmp,jtmp1, **jetJetOut;
  double xi,xnorm,dh;
  int i,j,k,nt,flag_endtime,flag_err;
  static int init=0;
#pragma omp threadprivate(s,h,mtmp,init)
#pragma omp threadprivate(jtmp,jtmp1,jetJetOut)

  if (init == 0) /* initialization of MY_FLOAT and MY_JET variables */
    {
      init=1;
      InitMyFloat(h);
      InitMyFloat(mtmp);
      xInitUpJet();
      xInitJet(jtmp);
      xInitJet(jtmp1);
    }
/*
  sup norm of the initial condition (jet included)
*/
  xnorm=0;
  if (step_ctl != 0)
    {
#if _J_DIM_ != 0
    for (i=0; i<_J_DIM_; i++)
      {
        xNormJet(mtmp,jetInOut[i]);
        MyFloatToDouble(xi,mtmp);
        xi=fabs(xi);
        if (xi > xnorm) xnorm=xi;
      }
#endif
      for (i=_J_DIM_; i<_N_DIM_; i++)
      {
        MyFloatToDouble(xi,x[i]);
        xi=fabs(xi);
        if (xi > xnorm) xnorm=xi;
      }
    }
/*
  we determine the degree of the taylor expansion.
  this value will be stored in the variable nt.
  the flag flag_err returns a value indicating if we are using an
  absolute error estimate (value 1) or a relative one (value 2).
*/
  switch(step_ctl)
    {
    case 0: /* no step size control, fixed degree; both given by the user */
      if (order==NULL)
      {
        fprintf(stderr,"step_ctl=%d needs an input order\n",step_ctl);
        exit(0);
      }
      nt=(*order<2)? 2: *order; /* 2 is the minimum order allowed */
      break;
    case 1:
      nt=compute_order_1_auto(xnorm,log10abserr,log10relerr,&flag_err);
      break;
    case 2:
      nt=compute_order_1_auto(xnorm,log10abserr,log10relerr,&flag_err);
      break;
    case -1:
      nt=comp_order_other_auto(xnorm,log10abserr,log10relerr);
      break;
    default:
      fprintf(stderr, "taylor_step: undefined step size control.\n");
      fprintf(stderr, "you must choose an existing step size control\n");
      fprintf(stderr, "method or supply a step size control procedure.\n");
      exit(0);
    }
  if (order!=NULL) *order=nt;
/*
  computation of the jet of derivatives up to order nt
*/
  if(step_ctl != 0) {
    s=taylor_coefficients_auto_A(*ti,x,nt,1, jetInOut, &jetJetOut);
  } else {
    s=taylor_coefficients_auto_A(*ti,x,nt,0, jetInOut, &jetJetOut); 
 }

/*
  selection of the routine to compute the time step. the value
  step_ctl=3 has been reserved for the user, in case she/he wants to
  code a different method.
*/
  dh=1.0;
  switch(step_ctl)
    {
    case 0: /* no step size control (fixed step size, given by the user) */
      if (ht==NULL)
      {
        fprintf(stderr,"step_ctl=%d needs an input stepsize\n",step_ctl);
        exit(0);
      }
      AssignMyFloat(h,*ht);
      break;
    case 1:
      dh=compute_stepsize_1_auto(s,jetJetOut,nt,xnorm,flag_err);
      MakeMyFloatA(h, dh);
      break;
    case 2:
      dh=compute_stepsize_2_auto(s,jetJetOut,nt,xnorm,flag_err);
      MakeMyFloatA(h, dh);
      break;
    case -1:
      dh=comp_stepsize_other_auto(s,jetJetOut,_N_DIM_,nt,xnorm,log10abserr,log10relerr);
      MakeMyFloatA(h, dh);
      break;
    default:
      fprintf(stderr, "taylor_step: undefined step size control.\n");
      fprintf(stderr, "You must choose an existing step size control\n");
      fprintf(stderr, "method or supply a step size control procedure.\n");
      exit(0);
    }
  if(dh == 0.0) return -1; //changeme
/*
  if step_ctl != 0, we adjust the sign of the computed stepsize.
*/
  flag_endtime=0;
  if (step_ctl != 0)
    {
      if (dir == -1) { NegateMyFloatA(mtmp,h); AssignMyFloat(h, mtmp);} 
/*
      we compare *ti+h with endtime. we modify h if necessary.
*/
      if (endtime != NULL)
        {
          AddMyFloatA(mtmp,h,*ti);
          if (dir == 1) /* time goes forward */
            {
              if (MyFloatA_GE_B(mtmp,*endtime))
                {
                  SubtractMyFloatA(h,*endtime,*ti);
                  flag_endtime=1;
                }
            }
            else /* time goes backwards */
            {
              if (MyFloatA_GE_B(*endtime,mtmp))
                {
                  SubtractMyFloatA(h,*endtime,*ti);
                  flag_endtime=1;
                }
            }
        }
    }
/*
  next lines are the summation of the taylor series (horner's method)
*/
  j=nt-1;
#if _J_DIM_ != 0
  for(i=0; i<_J_DIM_; i++)
  {
    xAssignJetToJet(jetInOut[i],jetJetOut[i][nt]);
    for(k=j; k>=0; k--)
    {
      xMultiplyFloatJetA(jtmp, h, jetInOut[i]);
      xAddJetJetA(jetInOut[i], jtmp, jetJetOut[i][k]);
    }
    xAssignJetToFloat(x[i],jetInOut[i]);
  }
#endif
  for(i=_J_DIM_; i<_N_DIM_; i++)
  {
    AssignMyFloat(x[i],s[i][nt]);
    for(k=j; k>=0; k--)
    {
      MultiplyMyFloatA(mtmp, h, x[i]);
      AddMyFloatA(x[i], mtmp, s[i][k]);
    }
  }
/*
  finally, we set the values of the parameters *ht and *ti.
*/
  if (ht!=NULL) AssignMyFloat(*ht,h);
  if (flag_endtime == 0)
    {
      AssignMyFloat(mtmp, *ti);
      AddMyFloatA(*ti, mtmp, h);
    }
    else
    {
      AssignMyFloat(*ti,*endtime);
    }
  return(flag_endtime);
}
int compute_order_1_auto(double xnorm, double log10abserr, double log10relerr, int* flag_err)
/*
 * this is to determine the 'optimal' degree of the taylor expansion.
 *
 * parameters:
 * xnorm: norm of the initial condition
 * log10abserr: base-10 log of the absolute error required
 * log10relerr: base-10 log of the relative error required
 * flag_err:    flag. returns 1 if absolute error is used
 *                    returns 2 if relative error is used
 *
 * returned value: 'optimal' degree.
*/
{
  double log10eps,tmp;
  int nt;

  log10eps=log10abserr;
  *flag_err=1;
  if (xnorm != (double)0.0)
    {
      tmp=log10relerr+log10(xnorm);
      if (tmp > log10abserr) {log10eps=log10relerr; *flag_err=2;}
    }
/*
  we use 1.16 for the value 0.5*log(10)=1.151292546497...
*/
  nt=(int)(1.5-1.16*log10eps);
  if (nt < 2) nt=2; /* this is the minimum order accepted */

#if DEBUG_LEVEL > 0
      fprintf(stderr, "taylor_step: order is %d\n",nt);
#endif

  return(nt);
}
double compute_stepsize_1_auto(MY_FLOAT **s, MY_JET **jet, int nt, double xnorm, int flag_err)
/*
 * it looks for a step size for an expansion up to order nt. this
 * function requires that nt is the value computed by
 * compute_order_1_
 */
{
  double double_log_MyFloat_auto(MY_FLOAT x);
  static MY_FLOAT z,v1,v2;
  static MY_FLOAT of,uf;
  double lnv1,lnv2,r,lnro1,lnro2,lnro;
  int i;
  static int init=0;
#pragma omp threadprivate(z,v1,v2,of,uf,init)

  if (init == 0)
    {
      init=1;
      InitMyFloat(z);
      InitMyFloat(v1);
      InitMyFloat(v2);
      InitMyFloat(of);
      InitMyFloat(uf);

      r=pow((double)2,(double)LEXP2);
      MakeMyFloatA(of,r);
      r=pow((double)2,(double)(-LEXP2));
      MakeMyFloatA(uf,r);
    }
/*
  we compute the sup norm of the last two coefficients of the taylor
  series, and we store them into v1 and v2.
*/
  MakeMyFloatA(v1,0);
  MakeMyFloatA(v2,0);
#if _J_DIM_ != 0
  for (i=0; i<_J_DIM_; i++)
  {
    xNormJet(z,jet[i][nt-1]);
    if (MyFloatA_GT_B(z,v1)) AssignMyFloat(v1,z);
    xNormJet(z,jet[i][nt]);
    if (MyFloatA_GT_B(z,v2)) AssignMyFloat(v2,z);
  }
#endif
  for(i=_J_DIM_; i<_N_DIM_; i++)
  {
    fabsMyFloatA(z,s[i][nt-1]);
    if (MyFloatA_GT_B(z,v1)) AssignMyFloat(v1,z);
    fabsMyFloatA(z,s[i][nt]);
    if (MyFloatA_GT_B(z,v2)) AssignMyFloat(v2,z);
  }
/*
  computation of the step size. we need the logs of v1 and v2, in
  double precision (there is no need for extended precision). the idea
  is to assign these variables to double variables and then to use the
  standard log function. before doing that, we have to be sure that v1
  can be assigned to a double without under or overflow. for this
  reason we will check for this condition and, if it fails, we will
  call an specific function for this case.
*/
  if (MyFloatA_LE_B(v1,of) && MyFloatA_GE_B(v1,uf))
    {
      MyFloatToDouble(r,v1);
      lnv1=log(r);
    }
    else
    {
      lnv1=double_log_MyFloat_auto(v1);
    }
  if (MyFloatA_LE_B(v2,of) && MyFloatA_GE_B(v2,uf))
    {
      MyFloatToDouble(r,v2);
      lnv2=log(r);
    }
    else
    {
      lnv2=double_log_MyFloat_auto(v2);
    }
  if(lnv1 == 65536.0 || lnv2 == 65536.0 ) return 0.0; //changeme
/*
  if flag_err == 2, this means that we are using a relative error control.
*/
  if (flag_err == 2)
    {
      r = -log10(xnorm);
      lnv1 += r;
      lnv2 += r;
    }
 lnro1= -lnv1/(nt-1);
 lnro2= -lnv2/nt;
 lnro=(lnro1 < lnro2)? lnro1: lnro2;

 r=exp(lnro-2-0.7/(nt-1)); /* exp(-0.7/(nt-1)) is a security factor */
  return(r);
}
double compute_stepsize_2_auto(MY_FLOAT **s, MY_JET **jet, int nt, double xnorm, int flag_err)
/*
 * it looks for a step size for an expansion up to order nt. this
 * function requires that nt is the value computed by
 * compute_order_1_. it also tries to reduce cancellations of big
 * terms in the summation of the taylor series.
 */
{
  double compute_stepsize_1_auto(MY_FLOAT**, MY_JET**, int, double, int);
  static MY_FLOAT h,hj,r,z,a,normj;
  double c,rtmp,dh;
  int i,j;
  static int init=0;
#pragma omp threadprivate(h,hj,r,z,a,normj,init)

  if (init == 0)
    {
      init=1;
      InitMyFloat(h); 
      InitMyFloat(hj);
      InitMyFloat(r);
      InitMyFloat(z);
      InitMyFloat(a);
      InitMyFloat(normj);
    }
/*
  we compute the step size according to the first algorithm
*/
  dh=compute_stepsize_1_auto(s,jet,nt,xnorm,flag_err);
  if(dh == 0.0) return  0.0; // changeme
  MakeMyFloatA(h,dh);
/*
  next lines select a value (z), that will be used to control the size
  of the terms of the Taylor series.
*/
  if (flag_err == 1) {
     MakeMyFloatA(z, 1.0);
  } else if (flag_err == 2) {
    MakeMyFloatA(z,xnorm);
  } else
    {
      printf("compute_stepsize_2 internal error. flag_err: %d\n",flag_err);
      exit(1);
    }
/*
  next loop checks if the sup norm of the terms in the Taylor series are
  lower than z. if a term is greater than z, the step size h is reduced.
*/
  MakeMyFloatA(hj,(double)1.0);

  for(j=1; j<=nt; j++)
  {
    MultiplyMyFloatA(r,h,hj);
    AssignMyFloat(hj,r);

    MakeMyFloatC(normj,"0", (double)0);
#if _J_DIM_ != 0
    for (i=0; i<_J_DIM_; i++)
    {
      xNormJet(a,jet[i][j]);
      if (MyFloatA_GT_B(a,normj)) AssignMyFloat(normj,a);
    }
#endif
    for (i=_J_DIM_; i<_N_DIM_; i++)
    {
      fabsMyFloatA(a,s[i][j]);
      if (MyFloatA_GT_B(a,normj)) AssignMyFloat(normj,a);
    }

    MultiplyMyFloatA(r,normj,hj);
    if (MyFloatA_LE_B(r,z)) continue;
/*
    we reduce h (and hj)
*/
    DivideMyFloatA(hj,z,normj);

    DivideMyFloatA(a,r,z);
    MyFloatToDouble(c,a);
    c=pow(c,(double)1.e0/(double)j);
    MakeMyFloatA(a,c);
    DivideMyFloatA(r,h,a);
    AssignMyFloat(h,r);

#if DEBUG_LEVEL > 1
    fprintf(stderr, "order %2d. reducing h from %14.6e to %14.6e\n",j,c*h,h);
#endif
  }

  MyFloatToDouble(rtmp,h);
  return(rtmp);
}

double double_log_MyFloat_auto(MY_FLOAT x)
/*
 * natural log, in double precision, of a MY_FLOAT positive number.
 */
{
  static MY_FLOAT a,tmp;
  static MY_FLOAT z,of,uf;
  double b,lx;
  int k;
  static int init=0;
#pragma omp threadprivate(a,tmp,z,of,uf,init)

  if (init == 0)
    {
      init=1;
      InitMyFloat(a);
      InitMyFloat(z);
      InitMyFloat(of);
      InitMyFloat(uf);
      InitMyFloat(tmp);

      b=0;
      MakeMyFloatA(z,b);
      b=pow((double)2,(double)LEXP2);
      MakeMyFloatA(of,b);
      b=pow((double)2,(double)(-LEXP2));
      MakeMyFloatA(uf,b);
    }

  if (MyFloatA_EQ_B(x,z))
    {
      puts("double_log_MyFloat error: zero argument");
      puts("(this is because one of the last two terms of your taylor");
      puts(" expansion is exactly zero)");
      /*exit(1);*/
      return 65536.0;
    }

  AssignMyFloat(a,x);

  k=0;
  while(MyFloatA_LT_B(a,uf))
  {
    ++k;
    if(k>3000){fprintf(stderr,"double_log_MyFloat overflow: %d\n", k); /*exit(1);*/ return 65536.0;}
     MultiplyMyFloatA(tmp,a,of);
    AssignMyFloat(a,tmp);
  }
  while(MyFloatA_GT_B(a,of))
  {
    --k;
    if(k<-3000){fprintf(stderr,"double_log_MyFloat underflow: %d\n", k); /*exit(1);*/ return 65536.0;}
     MultiplyMyFloatA(tmp,a,uf);
    AssignMyFloat(a,tmp);
  }

  MyFloatToDouble(b,a);
/*
  lx stands for log(x)
*/
  lx=log(b)-(LEXP2*0.69314718055994530942)*k;

  return(lx);
}


int comp_order_other_auto(double lnxnorm, double log10abserr, double log10relerr){
  puts("---");
  puts("compute_order_user_defined:");
  puts("you have to code this routine");
  puts("or select a different value for the step_ctl parameter");
  puts("---");
  exit(1);

  return(0);
}
double comp_stepsize_other_auto(MY_FLOAT **s, MY_JET **jet, int nd, int nt, double xnorm, double log10abserr, double log10relerr) {

  puts("---");
  puts("compute_timestep_user_defined:");
  puts("you have to code this routine");
  puts("or select a different value for the step_ctl parameter");
  puts("---");
  exit(1);
  return((double)0.00001);
}
static int _jet_1_monomial_counts_auto_[]  =      {1,6};
static int _jet_1_monomial_offsets_auto_[] =      {0,1,7};
/* MACROS TO LINK MY_FLOAT WITH MY_JET COEFFICIENTS */
#ifndef myfloat_t
#define myfloat_t          MY_FLOAT

#define myfloat_init       InitMyFloat
#define myfloat_clean      ClearMyFloat

/* assign */
#define myfloat_set        AssignMyFloat
#define myfloat_set_d      MakeMyFloatB
#define myfloat_set_si     MakeMyFloatB
#define myfloat_set_zero(r) MakeMyFloatC(r,"0",0)

/* elemental operations */
#define myfloat_add2       AddMyFloatA
#define myfloat_sub2       SubtractMyFloatA
#define myfloat_mul2       MultiplyMyFloatA
#define myfloat_div2       DivideMyFloatA

#define myfloat_add2_d     AddMyFloatD
#define myfloat_sub2_d     SubtractMyFloatD
#define myfloat_mul2_d     MultiplyMyFloatD
#define myfloat_div2_d     DivideMyFloatD
#define myfloat_d_sub2     SubtractDMyFloat
#define myfloat_d_div2     DivideDMyFloat

#define myfloat_add2_si    AddMyFloatSI
#define myfloat_sub2_si    SubtractMyFloatSI
#define myfloat_mul2_si    MultiplyMyFloatSI
#define myfloat_div2_si    DivideMyFloatSI
#define myfloat_si_sub2    SubtractSIMyFloat
#define myfloat_si_div2    DivideSIMyFloat

#define myfloat_neg        NegateMyFloatA

/* built-in functions */
#define myfloat_set_sqrt   sqrtMyFloatA
#define myfloat_set_pow    ExponentiateMyFloatA
#define myfloat_set_pow_si ExponentiateMyFloatIA

#define myfloat_set_sin    sinMyFloatA
#define myfloat_set_cos    cosMyFloatA
#define myfloat_set_tan    tanMyFloatA
#define myfloat_set_atan   atanMyFloatA
#define myfloat_set_exp    expMyFloatA
#define myfloat_set_log    logMyFloatA
#define myfloat_set_sinh   sinhMyFloatA
#define myfloat_set_cosh   coshMyFloatA
#define myfloat_set_tanh   tanhMyFloatA
#define myfloat_set_log10  log10MyFloatA
#define myfloat_set_fabs   fabsMyFloatA
#define myfloat_to_si      MyFloatToInt
#define myfloat_to_d       MyFloatToDouble

/* boolean operations */
#define myfloat_ge  MyFloatA_GE_B
#define myfloat_gt  MyFloatA_GT_B
#define myfloat_le  MyFloatA_LE_B
#define myfloat_lt  MyFloatA_LT_B
#define myfloat_eq  MyFloatA_EQ_B
#define myfloat_neq MyFloatA_NEQ_B

/* output format */
#define myfloat_fprintf OutputMyFloat3

/* input format */
#define myfloat_fscanf InputMyFloat3
#endif /* END myfloat_t */


/* BEGIN PRECODE mycoef_myfloat_t_auto */
#define mycoef_myfloat_t_auto          MY_COEF
/* END PRECODE mycoef_myfloat_t_auto */


/* BEGIN MY_COEF_MY_FLOAT_BASIC mycoef_myfloat_t_auto */
#define mycoef_myfloat_initup2_auto(s,d)    
#define mycoef_myfloat_initup_auto()        
#define mycoef_myfloat_init_auto            InitMyFloat
#define mycoef_myfloat_clean_auto           ClearMyFloat
#define mycoef_myfloat_cleanup_auto()       

/* assign */
#define mycoef_myfloat_set_auto             AssignMyFloat
#define mycoef_myfloat_set_myfloat_auto     AssignMyFloat
#define mycoef_myfloat_set_d_auto           MakeMyFloatB
#define mycoef_myfloat_set_si_auto          MakeMyFloatB
#define mycoef_myfloat_set_zero_auto(r)     MakeMyFloatC(r,"0",0)

/* elemental operations */
#define mycoef_myfloat_add2_auto            AddMyFloatA
#define mycoef_myfloat_sub2_auto            SubtractMyFloatA
#define mycoef_myfloat_mul2_auto            MultiplyMyFloatA
#define mycoef_myfloat_div2_auto            DivideMyFloatA

#define mycoef_myfloat_add2_myfloat_auto    AddMyFloatA
#define mycoef_myfloat_sub2_myfloat_auto    SubtractMyFloatA
#define mycoef_myfloat_mul2_myfloat_auto    MultiplyMyFloatA
#define mycoef_myfloat_div2_myfloat_auto    DivideMyFloatA
#define mycoef_myfloat_myfloat_sub2_auto    SubtractMyFloatA
#define mycoef_myfloat_myfloat_div2_auto    DivideMyFloatA

#define mycoef_myfloat_add2_d_auto          AddMyFloatD
#define mycoef_myfloat_sub2_d_auto          SubtractMyFloatD
#define mycoef_myfloat_mul2_d_auto          MultiplyMyFloatD
#define mycoef_myfloat_div2_d_auto          DivideMyFloatD
#define mycoef_myfloat_d_sub2_auto          SubtractDMyFloat
#define mycoef_myfloat_d_div2_auto          DivideDMyFloat

#define mycoef_myfloat_add2_si_auto         AddMyFloatSI
#define mycoef_myfloat_sub2_si_auto         SubtractMyFloatSI
#define mycoef_myfloat_mul2_si_auto         MultiplyMyFloatSI
#define mycoef_myfloat_div2_si_auto         DivideMyFloatSI
#define mycoef_myfloat_si_sub2_auto         SubtractSIMyFloat
#define mycoef_myfloat_si_div2_auto         DivideSIMyFloat

#define mycoef_myfloat_neg_auto             NegateMyFloatA

/* built-in functions */
#define mycoef_myfloat_set_sqrt_auto        sqrtMyFloatA
#define mycoef_myfloat_set_pow_myfloat_auto ExponentiateMyFloatA
#define mycoef_myfloat_set_pow_si_auto      ExponentiateMyFloatIA

#define mycoef_myfloat_set_sin_auto         sinMyFloatA
#define mycoef_myfloat_set_cos_auto         cosMyFloatA
#define mycoef_myfloat_set_tan_auto         tanMyFloatA
#define mycoef_myfloat_set_atan_auto        atanMyFloatA
#define mycoef_myfloat_set_exp_auto         expMyFloatA
#define mycoef_myfloat_set_log_auto         logMyFloatA
#define mycoef_myfloat_set_sinh_auto        sinhMyFloatA
#define mycoef_myfloat_set_cosh_auto        coshMyFloatA
#define mycoef_myfloat_set_tanh_auto        tanhMyFloatA
#define mycoef_myfloat_set_log10_auto       log10MyFloatA
#define mycoef_myfloat_set_fabs_auto        fabsMyFloatA

/* castings */
#define mycoef_myfloat_to_myfloat_auto(a)   &(a)
#define mycoef_myfloat_to_si_auto           MyFloatToInt
#define mycoef_myfloat_to_d_auto            MyFloatToDouble

/* boolean operations */
#define mycoef_myfloat_ge_auto  MyFloatA_GE_B
#define mycoef_myfloat_gt_auto  MyFloatA_GT_B
#define mycoef_myfloat_le_auto  MyFloatA_LE_B
#define mycoef_myfloat_lt_auto  MyFloatA_LT_B
#define mycoef_myfloat_eq_auto  MyFloatA_EQ_B
#define mycoef_myfloat_neq_auto MyFloatA_NEQ_B

/* norms */
#define mycoef_myfloat_nrminf_auto(a,b) mycoef_myfloat_set_fabs_auto(*(a),b)
#define mycoef_myfloat_nrm2_auto(a,b) mycoef_myfloat_mul2_auto(*(a),b,b)

/* output format */
#define mycoef_myfloat_fprintf_auto OutputMyFloat3

/* input format */
#define mycoef_myfloat_fscanf_auto InputMyFloat3

/* string scanf */
#define mycoef_myfloat_sscanf4_auto StringToMyFloat4
/* END MY_COEF_MY_FLOAT_BASIC mycoef_myfloat_t_auto */


/* BEGIN MY_COEF_MY_FLOAT_BASIC mycoef_myfloat_t_auto */
#define mycoef_myfloat_initup2_auto(s,d)    
#define mycoef_myfloat_initup_auto()        
#define mycoef_myfloat_init_auto            InitMyFloat
#define mycoef_myfloat_clean_auto           ClearMyFloat
#define mycoef_myfloat_cleanup_auto()       

/* assign */
#define mycoef_myfloat_set_auto             AssignMyFloat
#define mycoef_myfloat_set_myfloat_auto     AssignMyFloat
#define mycoef_myfloat_set_d_auto           MakeMyFloatB
#define mycoef_myfloat_set_si_auto          MakeMyFloatB
#define mycoef_myfloat_set_zero_auto(r)     MakeMyFloatC(r,"0",0)

/* elemental operations */
#define mycoef_myfloat_add2_auto            AddMyFloatA
#define mycoef_myfloat_sub2_auto            SubtractMyFloatA
#define mycoef_myfloat_mul2_auto            MultiplyMyFloatA
#define mycoef_myfloat_div2_auto            DivideMyFloatA

#define mycoef_myfloat_add2_myfloat_auto    AddMyFloatA
#define mycoef_myfloat_sub2_myfloat_auto    SubtractMyFloatA
#define mycoef_myfloat_mul2_myfloat_auto    MultiplyMyFloatA
#define mycoef_myfloat_div2_myfloat_auto    DivideMyFloatA
#define mycoef_myfloat_myfloat_sub2_auto    SubtractMyFloatA
#define mycoef_myfloat_myfloat_div2_auto    DivideMyFloatA

#define mycoef_myfloat_add2_d_auto          AddMyFloatD
#define mycoef_myfloat_sub2_d_auto          SubtractMyFloatD
#define mycoef_myfloat_mul2_d_auto          MultiplyMyFloatD
#define mycoef_myfloat_div2_d_auto          DivideMyFloatD
#define mycoef_myfloat_d_sub2_auto          SubtractDMyFloat
#define mycoef_myfloat_d_div2_auto          DivideDMyFloat

#define mycoef_myfloat_add2_si_auto         AddMyFloatSI
#define mycoef_myfloat_sub2_si_auto         SubtractMyFloatSI
#define mycoef_myfloat_mul2_si_auto         MultiplyMyFloatSI
#define mycoef_myfloat_div2_si_auto         DivideMyFloatSI
#define mycoef_myfloat_si_sub2_auto         SubtractSIMyFloat
#define mycoef_myfloat_si_div2_auto         DivideSIMyFloat

#define mycoef_myfloat_neg_auto             NegateMyFloatA

/* built-in functions */
#define mycoef_myfloat_set_sqrt_auto        sqrtMyFloatA
#define mycoef_myfloat_set_pow_myfloat_auto ExponentiateMyFloatA
#define mycoef_myfloat_set_pow_si_auto      ExponentiateMyFloatIA

#define mycoef_myfloat_set_sin_auto         sinMyFloatA
#define mycoef_myfloat_set_cos_auto         cosMyFloatA
#define mycoef_myfloat_set_tan_auto         tanMyFloatA
#define mycoef_myfloat_set_atan_auto        atanMyFloatA
#define mycoef_myfloat_set_exp_auto         expMyFloatA
#define mycoef_myfloat_set_log_auto         logMyFloatA
#define mycoef_myfloat_set_sinh_auto        sinhMyFloatA
#define mycoef_myfloat_set_cosh_auto        coshMyFloatA
#define mycoef_myfloat_set_tanh_auto        tanhMyFloatA
#define mycoef_myfloat_set_log10_auto       log10MyFloatA
#define mycoef_myfloat_set_fabs_auto        fabsMyFloatA

/* castings */
#define mycoef_myfloat_to_myfloat_auto(a)   &(a)
#define mycoef_myfloat_to_si_auto           MyFloatToInt
#define mycoef_myfloat_to_d_auto            MyFloatToDouble

/* boolean operations */
#define mycoef_myfloat_ge_auto  MyFloatA_GE_B
#define mycoef_myfloat_gt_auto  MyFloatA_GT_B
#define mycoef_myfloat_le_auto  MyFloatA_LE_B
#define mycoef_myfloat_lt_auto  MyFloatA_LT_B
#define mycoef_myfloat_eq_auto  MyFloatA_EQ_B
#define mycoef_myfloat_neq_auto MyFloatA_NEQ_B

/* norms */
#define mycoef_myfloat_nrminf_auto(a,b) mycoef_myfloat_set_fabs_auto(*(a),b)
#define mycoef_myfloat_nrm2_auto(a,b) mycoef_myfloat_mul2_auto(*(a),b,b)

/* output format */
#define mycoef_myfloat_fprintf_auto OutputMyFloat3

/* input format */
#define mycoef_myfloat_fscanf_auto InputMyFloat3

/* string scanf */
#define mycoef_myfloat_sscanf4_auto StringToMyFloat4
/* END MY_COEF_MY_FLOAT_BASIC mycoef_myfloat_t_auto */


/* BEGIN MY_COEF_MY_FLOAT_POSTCODE mycoef_myfloat_t_auto */
/* MACROS TO LINK MY_COEF */
#ifndef mycoef_t 
#define mycoef_t mycoef_myfloat_t_auto

#define mycoef_initup() mycoef_myfloat_initup2_auto(_MY_COEF_MAX_NUM_SYMBOLS_,_MY_COEF_MAX_DEGREE_)
#define mycoef_init(a)  mycoef_myfloat_init_auto((a))
#define mycoef_clean(a) mycoef_myfloat_clean_auto((a))
#define mycoef_cleanup  mycoef_myfloat_cleanup_auto

/* norm functions */
#define mycoef_nrminf mycoef_myfloat_nrminf_auto
#define mycoef_nrm2 mycoef_myfloat_nrm2_auto

/* casts */
#define mycoef_to_myfloat mycoef_myfloat_to_myfloat_auto

/* assign */
#define mycoef_set mycoef_myfloat_set_auto
#define mycoef_set_zero mycoef_myfloat_set_zero_auto
#define mycoef_set_myfloat mycoef_myfloat_set_myfloat_auto
#define mycoef_set_d mycoef_myfloat_set_d_auto
#define mycoef_set_si mycoef_myfloat_set_si_auto

/* elemental operations */
#define mycoef_add2 mycoef_myfloat_add2_auto
#define mycoef_sub2 mycoef_myfloat_sub2_auto
#define mycoef_mul2 mycoef_myfloat_mul2_auto
#define mycoef_div2 mycoef_myfloat_div2_auto

#define mycoef_add2_myfloat mycoef_myfloat_add2_myfloat_auto
#define mycoef_sub2_myfloat mycoef_myfloat_sub2_myfloat_auto
#define mycoef_myfloat_sub2 mycoef_myfloat_myfloat_sub2_auto
#define mycoef_mul2_myfloat mycoef_myfloat_mul2_myfloat_auto
#define mycoef_div2_myfloat mycoef_myfloat_div2_myfloat_auto
#define mycoef_myfloat_div2 mycoef_myfloat_myfloat_div2_auto

#define mycoef_add2_d mycoef_myfloat_add2_d_auto
#define mycoef_sub2_d mycoef_myfloat_sub2_d_auto
#define mycoef_mul2_d mycoef_myfloat_mul2_d_auto
#define mycoef_div2_d mycoef_myfloat_div2_d_auto
#define mycoef_d_sub2 mycoef_myfloat_d_sub2_auto
#define mycoef_d_div2 mycoef_myfloat_d_div2_auto

#define mycoef_add2_si mycoef_myfloat_add2_si_auto
#define mycoef_sub2_si mycoef_myfloat_sub2_si_auto
#define mycoef_mul2_si mycoef_myfloat_mul2_si_auto
#define mycoef_div2_si mycoef_myfloat_div2_si_auto
#define mycoef_si_sub2 mycoef_myfloat_si_sub2_auto
#define mycoef_si_div2 mycoef_myfloat_si_div2_auto

#define mycoef_neg mycoef_myfloat_neg_auto

/* built-in functions */
#define mycoef_set_sqrt mycoef_myfloat_set_sqrt_auto
#define mycoef_set_pow_myfloat mycoef_myfloat_set_pow_myfloat_auto
#define mycoef_set_pow_si mycoef_myfloat_set_pow_si_auto

#define mycoef_set_sin mycoef_myfloat_set_sin_auto
#define mycoef_set_cos mycoef_myfloat_set_cos_auto
#define mycoef_set_tan mycoef_myfloat_set_tan_auto
#define mycoef_set_atan mycoef_myfloat_set_atan_auto
#define mycoef_set_exp mycoef_myfloat_set_exp_auto
#define mycoef_set_log mycoef_myfloat_set_log_auto
#define mycoef_set_sinh mycoef_myfloat_set_sinh_auto
#define mycoef_set_cosh mycoef_myfloat_set_cosh_auto
#define mycoef_set_tanh mycoef_myfloat_set_tanh_auto
#define mycoef_set_log10 mycoef_myfloat_set_log10_auto
#define mycoef_set_fabs mycoef_myfloat_set_fabs_auto

/* castings */
#define mycoef_to_si mycoef_myfloat_to_si_auto
#define mycoef_to_d mycoef_myfloat_to_d_auto

/* boolean operations */
#define mycoef_ge mycoef_myfloat_ge_auto
#define mycoef_gt mycoef_myfloat_gt_auto
#define mycoef_le mycoef_myfloat_le_auto
#define mycoef_lt mycoef_myfloat_lt_auto
#define mycoef_eq mycoef_myfloat_eq_auto
#define mycoef_neq mycoef_myfloat_neq_auto

/* output format */
#define mycoef_fprintf mycoef_myfloat_fprintf_auto

/* input format */
#define mycoef_fscanf mycoef_myfloat_fscanf_auto

/* string scanf */
#define mycoef_sscanf4 mycoef_myfloat_sscanf4_auto
#endif /* END my_coef_t */

 
/* END MY_COEF_MY_FLOAT_POSTCODE mycoef_myfloat_t_auto */

/* MACROS TO LINK MY_COEF */
#ifndef mycoef_t 
#define mycoef_t mycoef_t

#define mycoef_initup() mycoef_initup2(_NUMBER_OF_MAX_SYMBOLS_,_MAX_DEGREE_OF_JET_VARS_)
#define mycoef_init(a)  mycoef_init(&(a))
#define mycoef_clean(a) mycoef_clean(&(a))
#define mycoef_cleanup  mycoef_cleanup

/* norm functions */
#define mycoef_nrminf mycoef_nrminf
#define mycoef_nrm2 mycoef_nrm2

/* casts */
#define mycoef_to_myfloat mycoef_to_myfloat

/* assign */
#define mycoef_set mycoef_set
#define mycoef_set_zero mycoef_set_zero
#define mycoef_set_myfloat mycoef_set_myfloat
#define mycoef_set_d mycoef_set_d
#define mycoef_set_si mycoef_set_si

/* elemental operations */
#define mycoef_add2 mycoef_add2
#define mycoef_sub2 mycoef_sub2
#define mycoef_mul2 mycoef_mul2
#define mycoef_div2 mycoef_div2

#define mycoef_add2_myfloat mycoef_add2_myfloat
#define mycoef_sub2_myfloat mycoef_sub2_myfloat
#define mycoef_myfloat_sub2 mycoef_myfloat_sub2
#define mycoef_mul2_myfloat mycoef_mul2_myfloat
#define mycoef_div2_myfloat mycoef_div2_myfloat
#define mycoef_myfloat_div2 mycoef_myfloat_div2

#define mycoef_add2_d mycoef_add2_d
#define mycoef_sub2_d mycoef_sub2_d
#define mycoef_mul2_d mycoef_mul2_d
#define mycoef_div2_d mycoef_div2_d
#define mycoef_d_sub2 mycoef_d_sub2
#define mycoef_d_div2 mycoef_d_div2

#define mycoef_add2_si mycoef_add2_si
#define mycoef_sub2_si mycoef_sub2_si
#define mycoef_mul2_si mycoef_mul2_si
#define mycoef_div2_si mycoef_div2_si
#define mycoef_si_sub2 mycoef_si_sub2
#define mycoef_si_div2 mycoef_si_div2

#define mycoef_neg mycoef_neg

/* built-in functions */
#define mycoef_set_sqrt mycoef_set_sqrt
#define mycoef_set_pow_myfloat mycoef_set_pow_myfloat
#define mycoef_set_pow_si mycoef_set_pow_si

#define mycoef_set_sin mycoef_set_sin
#define mycoef_set_cos mycoef_set_cos
#define mycoef_set_tan mycoef_set_tan
#define mycoef_set_atan mycoef_set_atan
#define mycoef_set_exp mycoef_set_exp
#define mycoef_set_log mycoef_set_log
#define mycoef_set_sinh mycoef_set_sinh
#define mycoef_set_cosh mycoef_set_cosh
#define mycoef_set_tanh mycoef_set_tanh
#define mycoef_set_log10 mycoef_set_log10
#define mycoef_set_fabs mycoef_set_fabs

/* castings */
#define mycoef_to_si mycoef_to_si
#define mycoef_to_d mycoef_to_d

/* boolean operations */
#define mycoef_ge mycoef_ge
#define mycoef_gt mycoef_gt
#define mycoef_le mycoef_le
#define mycoef_lt mycoef_lt
#define mycoef_eq mycoef_eq
#define mycoef_neq mycoef_neq

/* output format */
#define mycoef_fprintf mycoef_fprintf

/* input format */
#define mycoef_fscanf mycoef_fscanf

/* string scanf */
#define mycoef_sscanf4 mycoef_sscanf4
#endif /* END my_coef_t */


/* CODE FOR jet_1_t_auto */
int * jet_1_monomial_counts_auto(void) {return _jet_1_monomial_counts_auto_;}
int * jet_1_monomial_offsets_auto(void) {return _jet_1_monomial_offsets_auto_;}
#include <stdlib.h>
#include <stdio.h>
#include <math.h>
#include <string.h>



static int jet_1_flag_init_jet_library_auto=0;
static int jet_1_nsymb_auto=_NUMBER_OF_MAX_SYMBOLS_;
static myfloat_t jet_1_faux_auto;
static mycoef_t jet_1_caux_auto;
#pragma omp threadprivate(jet_1_flag_init_jet_library_auto,jet_1_faux_auto,jet_1_caux_auto)

size_t jet_1_init_auto(jet_1_ptr_auto x)
{
	size_t mem=0;
	int k;
	*x = (__typeof__(*x)) malloc((_JET_COEFFICIENTS_COUNT_TOTAL_)*sizeof(**x));
	if (*x == NULL) {
		fprintf(stderr, "not enough memory to allocate %d\n",_JET_COEFFICIENTS_COUNT_TOTAL_);
		exit(1);
	}
	for (k = 0; k < _JET_COEFFICIENTS_COUNT_TOTAL_; k++) {mycoef_init((*x)[k]);}
	mem+= (_JET_COEFFICIENTS_COUNT_TOTAL_)*sizeof(**x);
	return mem;
}

void jet_1_initup2_auto(int nsymbs, int deg)
{
	if (jet_1_flag_init_jet_library_auto==1) return;
	if (deg != 1) {
		fprintf(stderr, "%d: Not allowed deg value: %d!=1\n",__LINE__,deg);
		exit(1);
	}
	if (_NUMBER_OF_MAX_SYMBOLS_ < nsymbs) {
		fprintf(stderr, "%d: Not allowed nsymbs value %d<%d\n",__LINE__,_NUMBER_OF_MAX_SYMBOLS_,nsymbs);
		exit(1);
	}
	jet_1_nsymb_auto = nsymbs;
	mycoef_initup();
	myfloat_init(jet_1_faux_auto);
	mycoef_init(jet_1_caux_auto);
	jet_1_flag_init_jet_library_auto=1;
}

int jet_1_get_num_symbs_auto(void){return jet_1_nsymb_auto;}

int jet_1_get_deg_auto(void){return 1;}

int jet_1_set_num_symbs_auto(int nsymbs)
{
	int k;
	if (nsymbs > _NUMBER_OF_MAX_SYMBOLS_) {
		fprintf(stderr, "%d: Invalid num. variables %d > %d\n",__LINE__,nsymbs, _NUMBER_OF_MAX_SYMBOLS_);
		exit(1);
	}
	/* WARNING: in case of parallel region required out of the scope */
	k = jet_1_nsymb_auto;
	jet_1_nsymb_auto = nsymbs;
	return k;
}

int jet_1_set_deg_auto(int deg)
{
	fprintf(stderr, "%d: Action not allowed\n",__LINE__);
	exit(1);
	return 0;
}

void jet_1_clean_auto(jet_1_ptr_auto x)
{
	int k;
	if (*x == NULL) return;
	for (k = 0; k < _JET_COEFFICIENTS_COUNT_TOTAL_; k++) {mycoef_clean((*x)[k]);}
	free(*x); *x=NULL;
}

void jet_1_cleanup_auto(void)
{
	if (jet_1_flag_init_jet_library_auto==0) return;
	mycoef_clean(jet_1_caux_auto);
	myfloat_clean(jet_1_faux_auto);
	mycoef_cleanup();
	jet_1_nsymb_auto = 0;
	jet_1_flag_init_jet_library_auto=0;
}

void jet_1_set_auto(jet_1_t_auto b, jet_1_t_auto a)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_set(b[k],a[k]);}
}

void jet_1_set_coef_array_auto(jet_1_t_auto b, mycoef_t *a)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_set(b[k],a[k]);}
	}

void jet_1_set_jet_2_coef_array_auto(mycoef_t *b, jet_1_t_auto a)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_set(b[k],a[k]);}
	}

void jet_1_set_coef_auto(jet_1_t_auto b, mycoef_t a)
{
	int k;
	mycoef_set(b[0],a);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_set_zero(b[k]);}
}

void jet_1_set_myfloat_auto(jet_1_t_auto b, myfloat_t a)
{
	int k;
	mycoef_set_myfloat(b[0],a);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_set_zero(b[k]);}
}
void jet_1_set_d_auto(jet_1_t_auto b, double a)
{
	int k;
	mycoef_set_d(b[0],a);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_set_zero(b[k]);}
}
void jet_1_set_si_auto(jet_1_t_auto b, int a)
{
	int k;
	mycoef_set_si(b[0],a);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_set_zero(b[k]);}
}
myfloat_t* jet_1_to_myfloat_auto(jet_1_t_auto a) { return mycoef_to_myfloat(a[0]);}

void jet_1_eval_auto(mycoef_t t[1], jet_1_t_auto a, myfloat_t s[]) 
{
	int k;
	mycoef_set_zero(*t);
	for (k = 0; k < jet_1_nsymb_auto; k++) {
		mycoef_mul2_myfloat(jet_1_caux_auto,a[k+1],s[k]);
		mycoef_add2(*t,*t,jet_1_caux_auto);
	}
	mycoef_add2(*t,*t,a[0]);
}
void jet_1_nrminf_auto(myfloat_t nrm[1], jet_1_t_auto a)
{
	int k;
	/* WARNING initial value for nrm GIVEN!! */
	for (k = 0; k <= jet_1_nsymb_auto; k++) {
		mycoef_nrminf(&jet_1_faux_auto,a[k]);
		if (myfloat_lt(*nrm,jet_1_faux_auto)) {myfloat_set(*nrm,jet_1_faux_auto);}
	}
}

void jet_1_nrm2_auto(myfloat_t nrm[1], jet_1_t_auto a)
{
	int k;
	/* WARNING initial value for nrm GIVEN!! */
	for (k = 0; k <= jet_1_nsymb_auto; k++) {
		mycoef_nrm2(&jet_1_faux_auto,a[k]);
		myfloat_add2(*nrm,*nrm,jet_1_faux_auto);
	}
	myfloat_set_sqrt(*nrm,*nrm);
}

void jet_1_neg_auto(jet_1_t_auto b, jet_1_t_auto a)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_neg(b[k],a[k]);}
}

void jet_1_add2_auto(jet_1_t_auto c, jet_1_t_auto a, jet_1_t_auto b)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_add2(c[k],a[k],b[k]);}
}
void jet_1_sub2_auto(jet_1_t_auto c, jet_1_t_auto a, jet_1_t_auto b)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_sub2(c[k],a[k],b[k]);}
}
void jet_1_mul2_auto(jet_1_t_auto c, jet_1_t_auto a, jet_1_t_auto b)
{
	int k;
	/* c' = a'b + ab' */
	for (k = 1; k <= jet_1_nsymb_auto; k++) {
		mycoef_mul2(jet_1_caux_auto,a[k],b[0]);
		mycoef_mul2(c[k],a[0],b[k]);
		mycoef_add2(c[k],c[k],jet_1_caux_auto);
	}
	mycoef_mul2(c[0],a[0],b[0]);
}
void jet_1_div2_auto(jet_1_t_auto c, jet_1_t_auto a, jet_1_t_auto b)
{
	int k;
	/* c' = (a' - ab'/b)/b */
	for (k = 1; k <= jet_1_nsymb_auto; k++) {
		mycoef_set(jet_1_caux_auto,a[k]);
		mycoef_mul2(c[k],a[0],b[k]);
		mycoef_div2(c[k],c[k],b[0]);
		mycoef_sub2(c[k],jet_1_caux_auto,c[k]);
		mycoef_div2(c[k],c[k],b[0]);
	}
	mycoef_div2(c[0],a[0],b[0]);
}

void jet_1_add2_coef_auto(jet_1_t_auto c, jet_1_t_auto a, mycoef_t b)
{
	int k;
	mycoef_add2(c[0],a[0],b);
	if (c != a) for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_set(c[k],a[k]);}
}
void jet_1_sub2_coef_auto(jet_1_t_auto c, jet_1_t_auto a, mycoef_t b)
{
	int k;
	mycoef_sub2(c[0],a[0],b);
	if (c != a) for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_set(c[k],a[k]);}
}
void jet_1_coef_sub2_auto(jet_1_t_auto c, mycoef_t b, jet_1_t_auto a)
{
	int k;
	mycoef_sub2(c[0],b,a[0]);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_neg(c[k],a[k]);}
}
void jet_1_mul2_coef_auto(jet_1_t_auto c, jet_1_t_auto a, mycoef_t b)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_mul2(c[k],a[k],b);}
}
void jet_1_div2_coef_auto(jet_1_t_auto c, jet_1_t_auto a, mycoef_t b)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_div2(c[k],a[k],b);}
}
void jet_1_coef_div2_auto(jet_1_t_auto c, mycoef_t b, jet_1_t_auto a)
{
	int k;
	mycoef_div2(c[0],b,a[0]);
	mycoef_div2(jet_1_caux_auto,c[0],a[0]);
	mycoef_neg(jet_1_caux_auto,jet_1_caux_auto);
	/* c' = -b(a'/a)/a */
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_mul2(c[k],a[k],jet_1_caux_auto);}
}

void jet_1_add2_myfloat_auto(jet_1_t_auto c, jet_1_t_auto a, myfloat_t b)
{
	int k;
	mycoef_add2_myfloat(c[0],a[0],b);
	if (c != a) for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_set(c[k],a[k]);}
}
void jet_1_sub2_myfloat_auto(jet_1_t_auto c, jet_1_t_auto a, myfloat_t b)
{
	int k;
	mycoef_sub2_myfloat(c[0],a[0],b);
	if (c != a) for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_set(c[k],a[k]);}
}
void jet_1_myfloat_sub2_auto(jet_1_t_auto c, myfloat_t b, jet_1_t_auto a)
{
	int k;
	mycoef_sub2_myfloat (c[0],a[0],b);
	mycoef_neg(c[0],c[0]);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_neg(c[k],a[k]);}
}
void jet_1_mul2_myfloat_auto(jet_1_t_auto c, jet_1_t_auto a, myfloat_t b)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_mul2_myfloat(c[k],a[k],b);}
}
void jet_1_div2_myfloat_auto(jet_1_t_auto c, jet_1_t_auto a, myfloat_t b)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_div2_myfloat(c[k],a[k],b);}
}
void jet_1_myfloat_div2_auto(jet_1_t_auto c, myfloat_t b, jet_1_t_auto a)
{
	int k;
	mycoef_myfloat_div2(c[0],b,a[0]);
	mycoef_div2(jet_1_caux_auto,c[0],a[0]);
	mycoef_neg(jet_1_caux_auto,jet_1_caux_auto);
	/* c' = -b(a'/a)/a */
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_mul2(c[k],a[k],jet_1_caux_auto);}
}

void jet_1_add2_d_auto(jet_1_t_auto c, jet_1_t_auto a, double b)
{
	int k;
	mycoef_add2_d(c[0],a[0],b);
	if (c != a) for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_set(c[k],a[k]);}
}
void jet_1_sub2_d_auto(jet_1_t_auto c, jet_1_t_auto a, double b)
{
	int k;
	mycoef_sub2_d(c[0],a[0],b);
	if (c != a) for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_set(c[k],a[k]);}
}
void jet_1_d_sub2_auto(jet_1_t_auto c, double b, jet_1_t_auto a)
{
	int k;
	mycoef_sub2_d (c[0],a[0],b);
	mycoef_neg(c[0],c[0]);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_neg(c[k],a[k]);}
}
void jet_1_mul2_d_auto(jet_1_t_auto c, jet_1_t_auto a, double b)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_mul2_d(c[k],a[k],b);}
}
void jet_1_div2_d_auto(jet_1_t_auto c, jet_1_t_auto a, double b)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_div2_d(c[k],a[k],b);}
}
void jet_1_d_div2_auto(jet_1_t_auto c, double b, jet_1_t_auto a)
{
	int k;
	mycoef_d_div2(c[0],b,a[0]);
	mycoef_div2(jet_1_caux_auto,c[0],a[0]);
	mycoef_neg(jet_1_caux_auto,jet_1_caux_auto);
	/* c' = -b(a'/a)/a */
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_mul2(c[k],a[k],jet_1_caux_auto);}
}

void jet_1_add2_si_auto(jet_1_t_auto c, jet_1_t_auto a, int b)
{
	int k;
	mycoef_add2_si(c[0],a[0],b);
	if (c != a) for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_set(c[k],a[k]);}
}
void jet_1_sub2_si_auto(jet_1_t_auto c, jet_1_t_auto a, int b)
{
	int k;
	mycoef_sub2_si(c[0],a[0],b);
	if (c != a) for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_set(c[k],a[k]);}
}
void jet_1_si_sub2_auto(jet_1_t_auto c, int b, jet_1_t_auto a)
{
	int k;
	mycoef_sub2_si(c[0],a[0],b);
	mycoef_neg(c[0],c[0]);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_neg(c[k],a[k]);}
}
void jet_1_mul2_si_auto(jet_1_t_auto c, jet_1_t_auto a, int b)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_mul2_si(c[k],a[k],b);}
}
void jet_1_div2_si_auto(jet_1_t_auto c, jet_1_t_auto a, int b)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {mycoef_div2_si(c[k],a[k],b);}
}
void jet_1_si_div2_auto(jet_1_t_auto c, int b, jet_1_t_auto a)
{
	int k;
	mycoef_si_div2(c[0],b,a[0]);
	mycoef_div2(jet_1_caux_auto,c[0],a[0]);
	mycoef_neg(jet_1_caux_auto,jet_1_caux_auto);
	/* c' = -b(a'/a)/a */
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_mul2(c[k],a[k],jet_1_caux_auto);}
}

void jet_1_set_sqrt_auto(jet_1_t_auto s, jet_1_t_auto a)
{
	int k;
	/* s'=a'/(2s[0]) */
	mycoef_set_sqrt(s[0],a[0]);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {
		mycoef_div2(s[k],a[k],s[0]);
		mycoef_div2_si(s[k],s[k],2);
	}
}

void jet_1_set_pow_myfloat_auto(jet_1_t_auto p, jet_1_t_auto a, myfloat_t b)
{
	int k;
	myfloat_sub2_si(jet_1_faux_auto,b,1);
	/* p'= b p[0]/a[0] a' */
	mycoef_set_pow_myfloat(jet_1_caux_auto,a[0],jet_1_faux_auto);
	mycoef_mul2_myfloat(jet_1_caux_auto,jet_1_caux_auto,b);
	mycoef_set_pow_myfloat(p[0],a[0],b);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_mul2(p[k],a[k],jet_1_caux_auto);}
}

void jet_1_set_exp_auto(jet_1_t_auto e, jet_1_t_auto a)
{
	int k;
	/* e'=a'e[0] */
	mycoef_set_exp(e[0],a[0]);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_mul2(e[k],e[0],a[k]);}
}
void jet_1_set_log_auto(jet_1_t_auto l, jet_1_t_auto a)
{
	int k;
	/* l'=a'/a[0] */
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_div2(l[k],a[k],a[0]);}
	mycoef_set_log(l[0],a[0]);
}

void jet_1_set_sin_auto(jet_1_t_auto s, jet_1_t_auto a)
{
	int k;
	/* s'=cos(a[0])a' */
	mycoef_set_cos(jet_1_caux_auto,a[0]);
	mycoef_set_sin(s[0],a[0]);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_mul2(s[k],jet_1_caux_auto,a[k]);}
}
void jet_1_set_cos_auto(jet_1_t_auto c, jet_1_t_auto a)
{
	int k;
	/* c'=-sin(a[0])a' */
	mycoef_set_sin(jet_1_caux_auto,a[0]);
	mycoef_neg(jet_1_caux_auto,jet_1_caux_auto);
	mycoef_set_cos(c[0],a[0]);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_mul2(c[k],jet_1_caux_auto,a[k]);}
}
void jet_1_set_tan_auto(jet_1_t_auto t, jet_1_t_auto a)
{
	int k;
	/* t'= (1+tan(a[0])^2)a'*/
	mycoef_set_tan(t[0],a[0]);
	mycoef_mul2(jet_1_caux_auto,t[0],t[0]);
	mycoef_add2_si(jet_1_caux_auto,jet_1_caux_auto,1);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_mul2(t[k],a[k],jet_1_caux_auto);}
}
void jet_1_set_atan_auto(jet_1_t_auto t, jet_1_t_auto a)
{
	int k;
	/* t'= a'/(1+(a[0])^2)*/
	mycoef_set_atan(t[0],a[0]);
	mycoef_mul2(jet_1_caux_auto,a[0],a[0]);
	mycoef_add2_si(jet_1_caux_auto,jet_1_caux_auto,1);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_div2(t[k],a[k],jet_1_caux_auto);}
}
void jet_1_set_sinh_auto(jet_1_t_auto s, jet_1_t_auto a)
{
	int k;
	/* s'=cosh(a[0])a' */
	mycoef_set_cosh(jet_1_caux_auto,a[0]);
	mycoef_set_sinh(s[0],a[0]);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_mul2(s[k],jet_1_caux_auto,a[k]);}
}
void jet_1_set_cosh_auto(jet_1_t_auto c, jet_1_t_auto a)
{
	int k;
	/* c'=sinh(a[0])a' */
	mycoef_set_sinh(jet_1_caux_auto,a[0]);
	mycoef_set_cosh(c[0],a[0]);
	for (k = 1; k <= jet_1_nsymb_auto; k++) {mycoef_mul2(c[k],jet_1_caux_auto,a[k]);}
}
void jet_1_fprintf_auto(FILE *file, const char *fmt, jet_1_t_auto a)
{
	int k;
	for (k = 0; k <= jet_1_nsymb_auto; k++) {		mycoef_fprintf(file,fmt,a[k]);
	}
}
void jet_1_fscanf_auto(FILE *file, const char *fmt, jet_1_t_auto a)
{
	int k;
	for (k = 0; k < _JET_COEFFICIENTS_COUNT_TOTAL_; k++) {		mycoef_fscanf(file, fmt, MY_JET_DATA(a,k));
	}
}
static char *jet_1_sscanf4_auto(char *ptr, const char *myfmt, jet_1_t_auto a, int *l)
{
	int k;
	for (k = 0; k <_JET_COEFFICIENTS_COUNT_TOTAL_ && *ptr!='\0'; k++){
		ptr = mycoef_sscanf4(ptr, myfmt, MY_JET_DATA(a,k), l);
	}
	for ( ; k <_JET_COEFFICIENTS_COUNT_TOTAL_; k++) {mycoef_set_zero(MY_JET_DATA(a,k));}
	return ptr;
}
void jet_1_sscanf_auto(const char *str, const char *fmt, jet_1_t_auto a)
{
	int l;
	const int len=fmt?strnlen(fmt,128):0; /* NOTE: safety string length of 128 */
	char myfmt[len+3], *mystr = strdup(str);
	sprintf(myfmt, "%s%%n",fmt);
	jet_1_sscanf4_auto(mystr, myfmt, a, &l);
	free(mystr);
}

/* END CODE jet_1_t_auto */

/***********************************************************************
 *
 * Procedure generated by the TAYLOR translator. Do not edit!
 *
 * It needs the header file 'taylor.h' to compile.
 * Run taylor with the -header -o taylor.h option to generate a sample 'taylor.h'

 * Translation info is at the end of this file.
 * Version 2.1, May 26, 2023
 ***********************************************************************/

#include <stdio.h>
#include <stdlib.h>
MY_FLOAT **taylor_coefficients_auto_A(MY_FLOAT t, MY_FLOAT *x, int order, int rflag, MY_JET *sIn, MY_JET ***sOut)
{
   /* input: 
      t:     current value of the time variable 
      x:     array represent values of the state variables
      order: order of the taylor coefficients sought
      rflag: recompute flag. If you call this routine with one order 
             first, but then decided that you need a higher order of the
             taylor polynomial, you can pass 0 to rflag. This routine 
             will try to use the values already computed. Provided that 
             both x and t have not been changed, and you did not modify 
             the jet derivatives from the previous call.
      sIn:   array representing the input jet variables
             If NULL, the x values are assigned.
      sOut:  Pointer output jet variables
             If NULL, the pointer is not modified.
      Return Value:
            Two D Array, rows are the taylor coefficients of the
            state variables

     */

    static int          _jz_ivars[3];
    #pragma omp threadprivate( _jz_ivars)
    static MY_FLOAT     _jz_cvars[16];
    #pragma omp threadprivate( _jz_cvars)
    static MY_FLOAT     *_jz_jet[61],  *_jz_save = NULL, *_jz_oneOverN=NULL,*_jz_theNs=NULL;
    static MY_FLOAT     _jz_tvar1, _jz_tvar2, _jz_tvar3, _jz_tvar4; /* tmp vars */
    static MY_FLOAT     _jz_uvar1, _jz_uvar2; /* tmp vars */
    static MY_FLOAT     _jz_svar1, _jz_svar2, _jz_svar3, _jz_svar4, _jz_svar5; /* tmp vars */
    static MY_FLOAT     _jz_wvar3, _jz_wvar4; /* tmp vars */
    static MY_FLOAT     _jz_zvar1, _jz_zvar2; /* tmp vars */
    static MY_FLOAT     _jz_MyFloatZERO, _kthtmp;
    #pragma omp threadprivate(_jz_jet, _jz_save, _jz_oneOverN, _jz_theNs, _jz_tvar1, _jz_tvar2, _jz_tvar3, _jz_tvar4, _jz_uvar1, _jz_uvar2, _jz_svar1, _jz_svar2, _jz_svar3, _jz_svar4, _jz_svar5, _jz_wvar3, _jz_wvar4, _jz_zvar1, _jz_zvar2, _jz_MyFloatZERO, _kthtmp)
/* series bgn */
    static MY_JET       *_sjz_jet[52], *_sjz_save = NULL;
    static MY_JET     _sjz_tvar1, _sjz_tvar2, _sjz_tvar3, _sjz_tvar4; /* tmp vars */
    static MY_JET     _sjz_uvar1, _sjz_uvar2; /* tmp vars */
    static MY_JET     _sjz_svar1, _sjz_svar2, _sjz_svar3, _sjz_svar4, _sjz_svar5; /* tmp vars */
    static MY_JET     _sjz_wvar3, _sjz_wvar4; /* tmp vars */
    static MY_JET     _sjz_zvar1, _sjz_zvar2; /* tmp vars */
    static MY_JET     _kthStmp; /* tmp vars */
    #pragma omp threadprivate(_sjz_jet, _sjz_save, _sjz_tvar1, _sjz_tvar2, _sjz_tvar3, _sjz_tvar4, _sjz_uvar1, _sjz_uvar2, _sjz_svar1, _sjz_svar2, _sjz_svar3, _sjz_svar4, _sjz_svar5,  _sjz_wvar3, _sjz_wvar4, _sjz_zvar1, _sjz_zvar2, _kthStmp)
/* series end */
    static int          _jz_maxOrderUsed  = -1;
    static int          _jz_lastOrder = 0, _jz_initialized=0, _jz_ginitialized=0;
    int                 _jz_i, _jz_j, _jz_k, _jz_l, _jz_m, _jz_n, _jz_oorder ;
    #pragma omp threadprivate(_jz_maxOrderUsed,_jz_lastOrder, _jz_initialized, _jz_ginitialized)
    /* allocating memory if needed */
    if (_jz_maxOrderUsed < order )  { 
    	 if (_jz_ginitialized == 0) { 
    	   InitMyFloat(_jz_tvar1); InitMyFloat(_jz_tvar2);InitMyFloat(_jz_tvar3);InitMyFloat(_jz_tvar4);
    	   InitMyFloat(_jz_svar1); InitMyFloat(_jz_svar2);InitMyFloat(_jz_svar3);InitMyFloat(_jz_svar4);
    	   InitMyFloat(_jz_svar5); InitMyFloat(_jz_zvar1);InitMyFloat(_jz_zvar2);
    	   InitMyFloat(_jz_uvar1); InitMyFloat(_jz_uvar2);
    	   InitMyFloat(_jz_wvar3);InitMyFloat(_jz_wvar4);
    	   InitMyFloat(_jz_MyFloatZERO); InitMyFloat(_kthtmp);
    	   MakeMyFloatC(_jz_MyFloatZERO, "0", (double)0);
    	   for(_jz_i=0; _jz_i<16; _jz_i++) {
    	       InitMyFloat(_jz_cvars[_jz_i]);
    	   }
    	   /* series bgn */
    	   InitJet(_sjz_tvar1); InitJet(_sjz_tvar2);InitJet(_sjz_tvar3);InitJet(_sjz_tvar4);
    	   InitJet(_sjz_svar1); InitJet(_sjz_svar2);InitJet(_sjz_svar3);InitJet(_sjz_svar4);
    	   InitJet(_sjz_svar5); InitJet(_sjz_zvar1);InitJet(_sjz_zvar2);
    	   InitJet(_sjz_uvar1); InitJet(_sjz_uvar2);
    	   InitJet(_sjz_wvar3); InitJet(_sjz_wvar4);
    	   InitJet(_kthStmp);
    	   /* series end */
    	 }
    	 if (rflag > 0) rflag = 0; /* have to recompute everything */
    	 _jz_oorder=_jz_maxOrderUsed;
    	 _jz_maxOrderUsed  = order;
    	 if (_jz_ginitialized) { 
    	   for(_jz_i=0; _jz_i< _jz_oorder+1; _jz_i++) {ClearMyFloat(_jz_oneOverN[_jz_i]); ClearMyFloat(_jz_theNs[_jz_i]);}
    	   free(_jz_oneOverN); free(_jz_theNs);
    	 }
    	 _jz_theNs = (MY_FLOAT *)malloc((order+1) * sizeof(MY_FLOAT));
    	 _jz_oneOverN = (MY_FLOAT *)malloc((order+1) * sizeof(MY_FLOAT));
    	 for(_jz_i=0; _jz_i<order+1; _jz_i++) {InitMyFloat(_jz_oneOverN[_jz_i]);InitMyFloat(_jz_theNs[_jz_i]);}
    	 MakeMyFloatC(_jz_theNs[0],"0.0", (double)0.0);
    	 MakeMyFloatC(_jz_uvar1,"1.0", (double)1.0);
    	 for(_jz_i = 1; _jz_i <= order; _jz_i++) {
    		 AssignMyFloat(_jz_tvar2, _jz_theNs[_jz_i-1]);
    		 AddMyFloatA(_jz_theNs[_jz_i], _jz_tvar2, _jz_uvar1);
	}
    	 AssignMyFloat(_jz_oneOverN[0],_jz_uvar1);
    	 AssignMyFloat(_jz_oneOverN[1],_jz_uvar1);
    	 for(_jz_i = 2; _jz_i <= order; _jz_i++) {
    		 DivideMyFloatA(_jz_oneOverN[_jz_i], _jz_uvar1,_jz_theNs[_jz_i]);
	}
    	 if (_jz_ginitialized) {
    	    for(_jz_i=0; _jz_i<(_jz_oorder+1)*(61); _jz_i++) { ClearMyFloat(_jz_save[_jz_i]);} free(_jz_save);
	  /* series bgn */
    	    for(_jz_i=0; _jz_i<(_jz_oorder+1)*(52); _jz_i++) { ClearJet(_sjz_save[_jz_i]);} free(_sjz_save);
	  /* series end */
    	 }
    	 _jz_save = (MY_FLOAT *)malloc((order+1)* 61 *sizeof(MY_FLOAT));
    	 for(_jz_i=0; _jz_i<(order+1)*(61); _jz_i++) { InitMyFloat(_jz_save[_jz_i]);}
    	 for(_jz_j = 0, _jz_k = 0; _jz_j < 61 ;  _jz_j++, _jz_k += order+1) { _jz_jet[_jz_j] =& (_jz_save[_jz_k]); }
    	 /*s eries bgn */
    	 _sjz_save = (MY_JET *)malloc((order+1)* 52 *sizeof(MY_JET));
    	 for(_jz_i=0; _jz_i<(order+1)*(52); _jz_i++) { InitJet(_sjz_save[_jz_i]);}
    	 for(_jz_j = 0, _jz_k = 0; _jz_j < 52 ;  _jz_j++, _jz_k += order+1) { _sjz_jet[_jz_j] =& (_sjz_save[_jz_k]); }
    	 /* series end */
    	 /* nonautonomous, derivatves of time */
    	 MakeMyFloatA(_jz_jet[6][1], (double)1.0);
    	 for(_jz_i = 2; _jz_i <= order; _jz_i++) { MakeMyFloatA(_jz_jet[6][_jz_i], (double)0.0);}

    	 /* True constants, initialized only once. */
	 /* const: i_041=1 */
	 _jz_ivars[0]=1;
	 /* const: c_031=3.0033532813678653e-6 */
	 MakeMyFloatC(_jz_cvars[0],"3.0033532813678653e-6",(double)3.0033532813678653e-6);
	 /* minus: c_067=(i_041-c_031) */
	 SubtractMyFloatA(_jz_cvars[1], MakeMyFloatB(_jz_uvar1,(double)_jz_ivars[0]), _jz_cvars[0]);
	 /* mult: c_076=(c_031*c_031) */
	 MultiplyMyFloatA(_jz_cvars[2], _jz_cvars[0], _jz_cvars[0]);
	 /* const: i_045=2 */
	 _jz_ivars[1]=2;
	 /* mult: c_077=(c_031*i_045) */
	 MultiplyMyFloatA(_jz_cvars[3], _jz_cvars[0], MakeMyFloatB(_jz_tvar1,(double)_jz_ivars[1]));
	 /* const: c_047=3. */
	 MakeMyFloatC(_jz_cvars[4],"3.",(double)3.);
	 /* negate: c_081=(-c_047) */
	 NegateMyFloatA(_jz_cvars[5],_jz_cvars[4]);
	 /* div: c_082=(c_081/i_045) */
	 DivideMyFloatA(_jz_cvars[6], _jz_cvars[5], MakeMyFloatB(_jz_uvar1,(double)_jz_ivars[1]));
	 /* mult: c_090=(c_067*c_067) */
	 MultiplyMyFloatA(_jz_cvars[7], _jz_cvars[1], _jz_cvars[1]);
	 /* mult: c_085=(c_067*i_045) */
	 MultiplyMyFloatA(_jz_cvars[8], _jz_cvars[1], MakeMyFloatB(_jz_tvar1,(double)_jz_ivars[1]));
	 /* const: c_033=0.0009545888860950467 */
	 MakeMyFloatC(_jz_cvars[9],"0.0009545888860950467",(double)0.0009545888860950467);
	 /* const: c_037=5.2038 */
	 MakeMyFloatC(_jz_cvars[10],"5.2038",(double)5.2038);
	 /* mult: c_068=(c_037*c_037) */
	 MultiplyMyFloatA(_jz_cvars[11], _jz_cvars[10], _jz_cvars[10]);
	 /* const: i_029=0 */
	 _jz_ivars[2]=0;
	 /* const: c_035=0.9156638588046531 */
	 MakeMyFloatC(_jz_cvars[12],"0.9156638588046531",(double)0.9156638588046531);
	 /* negate: c_099=(-c_037) */
	 NegateMyFloatA(_jz_cvars[13],_jz_cvars[10]);
	 /* mult: c_069=(c_037*c_068) */
	 MultiplyMyFloatA(_jz_cvars[14], _jz_cvars[10], _jz_cvars[11]);
	 /* div: c_070=(c_033/c_069) */
	 DivideMyFloatA(_jz_cvars[15], _jz_cvars[9], _jz_cvars[14]);
    }

    if (rflag) {
    	 if (rflag < 0 ) return(NULL);
    	 if (MyFloatA_NEQ_B(t, _jz_jet[6][0])) rflag = 0;
    	 for(_jz_i = 0; rflag != 0 && _jz_i < 6; _jz_i++) {
    		 if (MyFloatA_NEQ_B(_jz_jet[_jz_i][0], x[_jz_i])) rflag = 0;
    	 }
    }

    if (rflag == 0) {
	 /* initialize all constant vars and state variables */
	 _jz_lastOrder = 1;
		 /* init state variable: */
	 AssignFloatToJet(_sjz_jet[0][0], x[0]);
	 AssignMyFloat(_jz_jet[0][0], x[0]);
		 /* init state variable: */
	 AssignFloatToJet(_sjz_jet[1][0], x[1]);
	 AssignMyFloat(_jz_jet[1][0], x[1]);
		 /* init state variable: */
	 AssignFloatToJet(_sjz_jet[2][0], x[2]);
	 AssignMyFloat(_jz_jet[2][0], x[2]);
		 /* init state variable: */
	 AssignFloatToJet(_sjz_jet[3][0], x[3]);
	 AssignMyFloat(_jz_jet[3][0], x[3]);
		 /* init state variable: */
	 AssignFloatToJet(_sjz_jet[4][0], x[4]);
	 AssignMyFloat(_jz_jet[4][0], x[4]);
		 /* init state variable: */
	 AssignFloatToJet(_sjz_jet[5][0], x[5]);
	 AssignMyFloat(_jz_jet[5][0], x[5]);
	 AssignMyFloat(_jz_jet[6][0], t); /* nonautonomous, time */
/* series bgn */
	 if (sIn){
		 AssignJetToJet(_sjz_jet[0][0], sIn[0]);
		 AssignJetToFloat(_jz_jet[0][0], sIn[0]);
		 AssignJetToJet(_sjz_jet[1][0], sIn[1]);
		 AssignJetToFloat(_jz_jet[1][0], sIn[1]);
		 AssignJetToJet(_sjz_jet[2][0], sIn[2]);
		 AssignJetToFloat(_jz_jet[2][0], sIn[2]);
		 AssignJetToJet(_sjz_jet[3][0], sIn[3]);
		 AssignJetToFloat(_jz_jet[3][0], sIn[3]);
		 AssignJetToJet(_sjz_jet[4][0], sIn[4]);
		 AssignJetToFloat(_jz_jet[4][0], sIn[4]);
		 AssignJetToJet(_sjz_jet[5][0], sIn[5]);
		 AssignJetToFloat(_jz_jet[5][0], sIn[5]);
	 }
/* series end */
	 /* plus: v_114=(v_023+v_025) */
	 AddJetJetA(_sjz_jet[6][0], _sjz_jet[1][0], _sjz_jet[3][0]);
	 /* minus: v_115=(v_026-v_022) */
	 SubtractJetJetA(_sjz_jet[7][0], _sjz_jet[4][0], _sjz_jet[0][0]);
	 /* mult: v_071=(v_022*v_022) */
	 MultiplyJetJetA(_sjz_jet[8][0], _sjz_jet[0][0], _sjz_jet[0][0]);
	 /* mult: v_072=(v_023*v_023) */
	 MultiplyJetJetA(_sjz_jet[9][0], _sjz_jet[1][0], _sjz_jet[1][0]);
	 /* plus: v_073=(v_071+v_072) */
	 AddJetJetA(_sjz_jet[10][0], _sjz_jet[8][0], _sjz_jet[9][0]);
	 /* mult: v_074=(v_024*v_024) */
	 MultiplyJetJetA(_sjz_jet[11][0], _sjz_jet[2][0], _sjz_jet[2][0]);
	 /* plus: v_075=(v_073+v_074) */
	 AddJetJetA(_sjz_jet[12][0], _sjz_jet[10][0], _sjz_jet[11][0]);
	 /* mult: v_078=(c_077*v_022) */
	 MultiplyFloatJetA(_sjz_jet[13][0], _jz_cvars[3], _sjz_jet[0][0]);
	 /* minus: v_079=(v_075-v_078) */
	 SubtractJetJetA(_sjz_jet[14][0], _sjz_jet[12][0], _sjz_jet[13][0]);
	 /* plus: v_080=(c_076+v_079) */
	 AddFloatJetA(_sjz_jet[15][0], _jz_cvars[2], _sjz_jet[14][0]);
	 /* exponentiation: v_083=(v_080^c_082) */
	 ExponentiateJetCstA(_sjz_jet[16][0], _sjz_jet[15][0], _jz_cvars[6]);
	 /* mult: v_116=(c_067*v_083) */
	 MultiplyFloatJetA(_sjz_jet[17][0], _jz_cvars[1], _sjz_jet[16][0]);
	 /* minus: v_117=(v_022-c_031) */
	 SubtractJetFloatA(_sjz_jet[18][0], _sjz_jet[0][0], _jz_cvars[0]);
	 /* mult: v_118=(v_116*v_117) */
	 MultiplyJetJetA(_sjz_jet[19][0], _sjz_jet[17][0], _sjz_jet[18][0]);
	 /* minus: v_119=(v_026-v_118) */
	 SubtractJetJetA(_sjz_jet[20][0], _sjz_jet[4][0], _sjz_jet[19][0]);
	 /* mult: v_086=(c_085*v_022) */
	 MultiplyFloatJetA(_sjz_jet[21][0], _jz_cvars[8], _sjz_jet[0][0]);
	 /* plus: v_087=(v_075+v_086) */
	 AddJetJetA(_sjz_jet[22][0], _sjz_jet[12][0], _sjz_jet[21][0]);
	 /* plus: v_091=(c_090+v_087) */
	 AddFloatJetA(_sjz_jet[23][0], _jz_cvars[7], _sjz_jet[22][0]);
	 /* exponentiation: v_094=(v_091^c_082) */
	 ExponentiateJetCstA(_sjz_jet[24][0], _sjz_jet[23][0], _jz_cvars[6]);
	 /* mult: v_120=(c_031*v_094) */
	 MultiplyFloatJetA(_sjz_jet[25][0], _jz_cvars[0], _sjz_jet[24][0]);
	 /* plus: v_121=(c_067+v_022) */
	 AddFloatJetA(_sjz_jet[26][0], _jz_cvars[1], _sjz_jet[0][0]);
	 /* mult: v_122=(v_120*v_121) */
	 MultiplyJetJetA(_sjz_jet[27][0], _sjz_jet[25][0], _sjz_jet[26][0]);
	 /* minus: v_123=(v_119-v_122) */
	 SubtractJetJetA(_sjz_jet[28][0], _sjz_jet[20][0], _sjz_jet[27][0]);
	 /* mult: v_095=(c_035*v_028) */
	 MultiplyMyFloatA(_jz_jet[30][0], _jz_cvars[12], _jz_jet[6][0]);
	 /* plus: v_096=(i_029+v_095) */
	 AddMyFloatA(_jz_jet[31][0], MakeMyFloatB(_jz_uvar1,(double)_jz_ivars[2]), _jz_jet[30][0]);
	 /* call: v_097=cos(v_096) */
	 cosMyFloatA(_jz_jet[32][0], _jz_jet[31][0]);
	 /* call: v_102=sin(v_096) */
	 sinMyFloatA(_jz_jet[33][0], _jz_jet[31][0]);
	 /* mult: v_098=(c_037*v_097) */
	 MultiplyMyFloatA(_jz_jet[34][0], _jz_cvars[10], _jz_jet[32][0]);
	 /* mult: v_105=(v_022*v_098) */
	 MultiplyJetFloatA(_sjz_jet[29][0], _sjz_jet[0][0], _jz_jet[34][0]);
	 /* mult: v_103=(c_099*v_102) */
	 MultiplyMyFloatA(_jz_jet[36][0], _jz_cvars[13], _jz_jet[33][0]);
	 /* mult: v_106=(v_023*v_103) */
	 MultiplyJetFloatA(_sjz_jet[30][0], _sjz_jet[1][0], _jz_jet[36][0]);
	 /* plus: v_107=(v_105+v_106) */
	 AddJetJetA(_sjz_jet[31][0], _sjz_jet[29][0], _sjz_jet[30][0]);
	 /* mult: v_108=(i_045*v_107) */
	 MultiplyFloatJetA(_sjz_jet[32][0], MakeMyFloatB(_jz_tvar1,(double)_jz_ivars[1]), _sjz_jet[31][0]);
	 /* minus: v_109=(v_075-v_108) */
	 SubtractJetJetA(_sjz_jet[33][0], _sjz_jet[12][0], _sjz_jet[32][0]);
	 /* plus: v_110=(c_068+v_109) */
	 AddFloatJetA(_sjz_jet[34][0], _jz_cvars[11], _sjz_jet[33][0]);
	 /* exponentiation: v_113=(v_110^c_082) */
	 ExponentiateJetCstA(_sjz_jet[35][0], _sjz_jet[34][0], _jz_cvars[6]);
	 /* mult: v_124=(c_033*v_113) */
	 MultiplyFloatJetA(_sjz_jet[36][0], _jz_cvars[9], _sjz_jet[35][0]);
	 /* minus: v_125=(v_022-v_098) */
	 SubtractJetFloatA(_sjz_jet[37][0], _sjz_jet[0][0], _jz_jet[34][0]);
	 /* mult: v_126=(v_124*v_125) */
	 MultiplyJetJetA(_sjz_jet[38][0], _sjz_jet[36][0], _sjz_jet[37][0]);
	 /* minus: v_127=(v_123-v_126) */
	 SubtractJetJetA(_sjz_jet[39][0], _sjz_jet[28][0], _sjz_jet[38][0]);
	 /* mult: v_128=(c_070*v_098) */
	 MultiplyMyFloatA(_jz_jet[47][0], _jz_cvars[15], _jz_jet[34][0]);
	 /* minus: v_129=(v_127-v_128) */
	 SubtractJetFloatA(_sjz_jet[40][0], _sjz_jet[39][0], _jz_jet[47][0]);
	 /* negate: v_130=(-v_025) */
	 NegateJetA(_sjz_jet[41][0],_sjz_jet[3][0]);
	 /* plus: v_133=(v_116+v_120) */
	 AddJetJetA(_sjz_jet[42][0], _sjz_jet[17][0], _sjz_jet[25][0]);
	 /* mult: v_134=(v_023*v_133) */
	 MultiplyJetJetA(_sjz_jet[43][0], _sjz_jet[1][0], _sjz_jet[42][0]);
	 /* minus: v_135=(v_130-v_134) */
	 SubtractJetJetA(_sjz_jet[44][0], _sjz_jet[41][0], _sjz_jet[43][0]);
	 /* minus: v_137=(v_023-v_103) */
	 SubtractJetFloatA(_sjz_jet[45][0], _sjz_jet[1][0], _jz_jet[36][0]);
	 /* mult: v_138=(v_124*v_137) */
	 MultiplyJetJetA(_sjz_jet[46][0], _sjz_jet[36][0], _sjz_jet[45][0]);
	 /* minus: v_139=(v_135-v_138) */
	 SubtractJetJetA(_sjz_jet[47][0], _sjz_jet[44][0], _sjz_jet[46][0]);
	 /* mult: v_140=(c_070*v_103) */
	 MultiplyMyFloatA(_jz_jet[56][0], _jz_cvars[15], _jz_jet[36][0]);
	 /* minus: v_141=(v_139-v_140) */
	 SubtractJetFloatA(_sjz_jet[48][0], _sjz_jet[47][0], _jz_jet[56][0]);
	 /* plus: v_146=(v_124+v_133) */
	 AddJetJetA(_sjz_jet[49][0], _sjz_jet[36][0], _sjz_jet[42][0]);
	 /* negate: v_147=(-v_146) */
	 NegateJetA(_sjz_jet[50][0],_sjz_jet[49][0]);
	 /* mult: v_148=(v_024*v_147) */
	 MultiplyJetJetA(_sjz_jet[51][0], _sjz_jet[2][0], _sjz_jet[50][0]);

	 /* the first derivative of state variables */
	 /* state variable 0: */
	 AssignJetToJet(_sjz_jet[0][1], _sjz_jet[6][0]);
	 AssignJetToFloat(_jz_jet[0][1], _sjz_jet[0][1]);
	 /* state variable 1: */
	 AssignJetToJet(_sjz_jet[1][1], _sjz_jet[7][0]);
	 AssignJetToFloat(_jz_jet[1][1], _sjz_jet[1][1]);
	 /* state variable 2: */
	 AssignJetToJet(_sjz_jet[2][1], _sjz_jet[5][0]);
	 AssignJetToFloat(_jz_jet[2][1], _sjz_jet[2][1]);
	 /* state variable 3: */
	 AssignJetToJet(_sjz_jet[3][1], _sjz_jet[40][0]);
	 AssignJetToFloat(_jz_jet[3][1], _sjz_jet[3][1]);
	 /* state variable 4: */
	 AssignJetToJet(_sjz_jet[4][1], _sjz_jet[48][0]);
	 AssignJetToFloat(_jz_jet[4][1], _sjz_jet[4][1]);
	 /* state variable 5: */
	 AssignJetToJet(_sjz_jet[5][1], _sjz_jet[51][0]);
	 AssignJetToFloat(_jz_jet[5][1], _sjz_jet[5][1]);
	 /* nonautonomous, time'=1 has been initialized already */
	}

	 /* compute the kth order derivatives of all vars */
	 for(_jz_k = _jz_lastOrder; _jz_k < order; _jz_k++) {
		 /* derivative for tmp variables */
		 /* plus: v_114=(v_023+v_025) */
		 AddJetJetA(_sjz_jet[6][_jz_k], _sjz_jet[1][_jz_k],_sjz_jet[3][_jz_k]);
		 /* minus: v_115=(v_026-v_022) */
		 SubtractJetJetA(_sjz_jet[7][_jz_k], _sjz_jet[4][_jz_k],_sjz_jet[0][_jz_k]);
		 /* mult: v_071=(v_022*v_022) */
		 { /* multiplication */
			 static MY_FLOAT tmp1, tmp2, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp)
			 static MY_JET stmp1, stmp2, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp)
			 if(_jz_initialized==0) {
			   InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp);
			   InitJet(stmp1);InitJet(stmp2); InitJet(stmp);
			   }
			 int parity=(_jz_k&1), half=(_jz_k+1)>>1;
			 AssignFloatToJet(stmp, _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<half; _jz_l++) {
			     MultiplyJetJetA(stmp1, _sjz_jet[0][_jz_l], _sjz_jet[0][_jz_k-_jz_l]);
			     AssignJetToJet(stmp2, stmp);
			     AddJetJetA(stmp, stmp2, stmp1);
			 }
			 AssignJetToJet(stmp2, stmp);
			 AddJetJetA(stmp1, stmp2, stmp);
			 if(parity==0) {
			     MultiplyJetJetA(stmp2, _sjz_jet[0][half], _sjz_jet[0][half]);
			     AddJetJetA(_sjz_jet[8][_jz_k], stmp2, stmp1);
			 } else {
			     AssignJetToJet(_sjz_jet[8][_jz_k], stmp1);
			 }
		 }
		 /* mult: v_072=(v_023*v_023) */
		 { /* multiplication */
			 static MY_FLOAT tmp1, tmp2, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp)
			 static MY_JET stmp1, stmp2, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp)
			 if(_jz_initialized==0) {
			   InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp);
			   InitJet(stmp1);InitJet(stmp2); InitJet(stmp);
			   }
			 int parity=(_jz_k&1), half=(_jz_k+1)>>1;
			 AssignFloatToJet(stmp, _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<half; _jz_l++) {
			     MultiplyJetJetA(stmp1, _sjz_jet[1][_jz_l], _sjz_jet[1][_jz_k-_jz_l]);
			     AssignJetToJet(stmp2, stmp);
			     AddJetJetA(stmp, stmp2, stmp1);
			 }
			 AssignJetToJet(stmp2, stmp);
			 AddJetJetA(stmp1, stmp2, stmp);
			 if(parity==0) {
			     MultiplyJetJetA(stmp2, _sjz_jet[1][half], _sjz_jet[1][half]);
			     AddJetJetA(_sjz_jet[9][_jz_k], stmp2, stmp1);
			 } else {
			     AssignJetToJet(_sjz_jet[9][_jz_k], stmp1);
			 }
		 }
		 /* plus: v_073=(v_071+v_072) */
		 AddJetJetA(_sjz_jet[10][_jz_k], _sjz_jet[8][_jz_k],_sjz_jet[9][_jz_k]);
		 /* mult: v_074=(v_024*v_024) */
		 { /* multiplication */
			 static MY_FLOAT tmp1, tmp2, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp)
			 static MY_JET stmp1, stmp2, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp)
			 if(_jz_initialized==0) {
			   InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp);
			   InitJet(stmp1);InitJet(stmp2); InitJet(stmp);
			   }
			 int parity=(_jz_k&1), half=(_jz_k+1)>>1;
			 AssignFloatToJet(stmp, _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<half; _jz_l++) {
			     MultiplyJetJetA(stmp1, _sjz_jet[2][_jz_l], _sjz_jet[2][_jz_k-_jz_l]);
			     AssignJetToJet(stmp2, stmp);
			     AddJetJetA(stmp, stmp2, stmp1);
			 }
			 AssignJetToJet(stmp2, stmp);
			 AddJetJetA(stmp1, stmp2, stmp);
			 if(parity==0) {
			     MultiplyJetJetA(stmp2, _sjz_jet[2][half], _sjz_jet[2][half]);
			     AddJetJetA(_sjz_jet[11][_jz_k], stmp2, stmp1);
			 } else {
			     AssignJetToJet(_sjz_jet[11][_jz_k], stmp1);
			 }
		 }
		 /* plus: v_075=(v_073+v_074) */
		 AddJetJetA(_sjz_jet[12][_jz_k], _sjz_jet[10][_jz_k],_sjz_jet[11][_jz_k]);
		 /* mult: v_078=(c_077*v_022) */
		 MultiplyFloatJetA(_sjz_jet[13][_jz_k], _jz_cvars[3], _sjz_jet[0][_jz_k]);
		 /* minus: v_079=(v_075-v_078) */
		 SubtractJetJetA(_sjz_jet[14][_jz_k], _sjz_jet[12][_jz_k],_sjz_jet[13][_jz_k]);
		 /* plus: v_080=(c_076+v_079) */
		 AssignJetToJet(_sjz_jet[15][_jz_k], _sjz_jet[14][_jz_k]);
		 /* exponentiation: v_083=(v_080^c_082) */
		 { /* exponentiation */
				 /* expr^(-3/2)/ */ 
			 int  ppk=(-3)*_jz_k, qqk=(2)*_jz_k, pq=-1;
			 static MY_FLOAT tmp1, tmp2, tmp3, tmpC, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp3, tmpC, tmp)
			 static MY_JET stmp1, stmp2, stmp3, stmpC, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp3, stmpC, stmp)
			 if(_jz_initialized==0) {
			  InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp3);
			  InitMyFloat(tmpC);InitMyFloat(tmp);
				  InitJet(stmp1);InitJet(stmp2);InitJet(stmp3);InitJet(stmpC);InitJet(stmp);
			 }
			 AssignFloatToJet(stmp,  _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<_jz_k; _jz_l++) {
			     MakeMyFloatA(tmpC, ppk);
			     AssignFloatToJet(stmpC, tmpC);
			     ppk -= pq  ;
			     MultiplyJetJetA(stmp1, _sjz_jet[16][_jz_l],_sjz_jet[15][_jz_k-_jz_l]);
			     MultiplyJetJetA(stmp2, stmpC, stmp1);
			     AddJetJetA(stmp1,  stmp, stmp2);
			     AssignJetToJet(stmp,  stmp1);
			 }
			 MakeMyFloatA(tmp3,qqk);
			 AssignFloatToJet(stmp3,tmp3);
			 MultiplyJetJetA(stmp1, _sjz_jet[15][0], stmp3);
			 DivideJetJetA(_sjz_jet[16][_jz_k], stmp, stmp1);
		}
		 /* mult: v_116=(c_067*v_083) */
		 MultiplyFloatJetA(_sjz_jet[17][_jz_k], _jz_cvars[1], _sjz_jet[16][_jz_k]);
		 /* minus: v_117=(v_022-c_031) */
		 AssignJetToJet(_sjz_jet[18][_jz_k], _sjz_jet[0][_jz_k]);
		 /* mult: v_118=(v_116*v_117) */
		 { /* multiplication */
			 static MY_FLOAT tmp1, tmp2, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp)
			 static MY_JET stmp1, stmp2, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp)
			 if(_jz_initialized==0) {
			   InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp);
			   InitJet(stmp1);InitJet(stmp2); InitJet(stmp);
			   }
			 AssignFloatToJet(stmp, _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<=_jz_k; _jz_l++) {
			     MultiplyJetJetA(stmp1, _sjz_jet[17][_jz_l], _sjz_jet[18][_jz_k-_jz_l]);
			     AssignJetToJet(stmp2, stmp);
			     AddJetJetA(stmp, stmp2, stmp1);
			 }
			 AssignJetToJet(_sjz_jet[19][_jz_k], stmp);
		 }
		 /* minus: v_119=(v_026-v_118) */
		 SubtractJetJetA(_sjz_jet[20][_jz_k], _sjz_jet[4][_jz_k],_sjz_jet[19][_jz_k]);
		 /* mult: v_086=(c_085*v_022) */
		 MultiplyFloatJetA(_sjz_jet[21][_jz_k], _jz_cvars[8], _sjz_jet[0][_jz_k]);
		 /* plus: v_087=(v_075+v_086) */
		 AddJetJetA(_sjz_jet[22][_jz_k], _sjz_jet[12][_jz_k],_sjz_jet[21][_jz_k]);
		 /* plus: v_091=(c_090+v_087) */
		 AssignJetToJet(_sjz_jet[23][_jz_k], _sjz_jet[22][_jz_k]);
		 /* exponentiation: v_094=(v_091^c_082) */
		 { /* exponentiation */
				 /* expr^(-3/2)/ */ 
			 int  ppk=(-3)*_jz_k, qqk=(2)*_jz_k, pq=-1;
			 static MY_FLOAT tmp1, tmp2, tmp3, tmpC, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp3, tmpC, tmp)
			 static MY_JET stmp1, stmp2, stmp3, stmpC, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp3, stmpC, stmp)
			 if(_jz_initialized==0) {
			  InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp3);
			  InitMyFloat(tmpC);InitMyFloat(tmp);
				  InitJet(stmp1);InitJet(stmp2);InitJet(stmp3);InitJet(stmpC);InitJet(stmp);
			 }
			 AssignFloatToJet(stmp,  _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<_jz_k; _jz_l++) {
			     MakeMyFloatA(tmpC, ppk);
			     AssignFloatToJet(stmpC, tmpC);
			     ppk -= pq  ;
			     MultiplyJetJetA(stmp1, _sjz_jet[24][_jz_l],_sjz_jet[23][_jz_k-_jz_l]);
			     MultiplyJetJetA(stmp2, stmpC, stmp1);
			     AddJetJetA(stmp1,  stmp, stmp2);
			     AssignJetToJet(stmp,  stmp1);
			 }
			 MakeMyFloatA(tmp3,qqk);
			 AssignFloatToJet(stmp3,tmp3);
			 MultiplyJetJetA(stmp1, _sjz_jet[23][0], stmp3);
			 DivideJetJetA(_sjz_jet[24][_jz_k], stmp, stmp1);
		}
		 /* mult: v_120=(c_031*v_094) */
		 MultiplyFloatJetA(_sjz_jet[25][_jz_k], _jz_cvars[0], _sjz_jet[24][_jz_k]);
		 /* plus: v_121=(c_067+v_022) */
		 AssignJetToJet(_sjz_jet[26][_jz_k], _sjz_jet[0][_jz_k]);
		 /* mult: v_122=(v_120*v_121) */
		 { /* multiplication */
			 static MY_FLOAT tmp1, tmp2, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp)
			 static MY_JET stmp1, stmp2, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp)
			 if(_jz_initialized==0) {
			   InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp);
			   InitJet(stmp1);InitJet(stmp2); InitJet(stmp);
			   }
			 AssignFloatToJet(stmp, _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<=_jz_k; _jz_l++) {
			     MultiplyJetJetA(stmp1, _sjz_jet[25][_jz_l], _sjz_jet[26][_jz_k-_jz_l]);
			     AssignJetToJet(stmp2, stmp);
			     AddJetJetA(stmp, stmp2, stmp1);
			 }
			 AssignJetToJet(_sjz_jet[27][_jz_k], stmp);
		 }
		 /* minus: v_123=(v_119-v_122) */
		 SubtractJetJetA(_sjz_jet[28][_jz_k], _sjz_jet[20][_jz_k],_sjz_jet[27][_jz_k]);
		 /* mult: v_095=(c_035*v_028) */
		 if(_jz_k==1) {AssignMyFloat(_jz_jet[30][_jz_k], _jz_cvars[12]);}
		 else {AssignMyFloat(_jz_jet[30][_jz_k], _jz_MyFloatZERO);}
		 /* plus: v_096=(i_029+v_095) */
		 AssignMyFloat(_jz_jet[31][_jz_k], _jz_jet[30][_jz_k]);
		 /* call: v_097=cos(v_096) */
		 { /* call cos sin */
			 static MY_FLOAT tmp, tmp1, tmp2, tmp3;
			 #pragma omp threadprivate(tmp, tmp1, tmp2, tmp3)
			 if(_jz_initialized==0) {
			  InitMyFloat(tmp1);InitMyFloat(tmp2);InitMyFloat(tmp3);InitMyFloat(tmp);
			 }
			 DivideMyFloatA(tmp, _jz_cvars[12], _jz_theNs[_jz_k]);
			 MultiplyMyFloatA(tmp2, tmp, _jz_jet[33][_jz_k-1]);
			 NegateMyFloatA(tmp1, tmp2);
			 AssignMyFloat(_jz_jet[32][_jz_k], tmp1);
			 MultiplyMyFloatA(_jz_jet[33][_jz_k], _jz_jet[32][_jz_k-1], tmp);
		 }
		 /* call: v_102=sin(v_096) */
			 /* computed already */
		 /* mult: v_098=(c_037*v_097) */
		 MultiplyMyFloatA(_jz_jet[34][_jz_k], _jz_cvars[10], _jz_jet[32][_jz_k]);
		 /* mult: v_105=(v_022*v_098) */
		 { /* multiplication */
			 static MY_FLOAT tmp1, tmp2, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp)
			 static MY_JET stmp1, stmp2, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp)
			 if(_jz_initialized==0) {
			   InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp);
			   InitJet(stmp1);InitJet(stmp2); InitJet(stmp);
			   }
			 AssignFloatToJet(stmp, _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<=_jz_k; _jz_l++) {
			     MultiplyJetFloatA(stmp1, _sjz_jet[0][_jz_l], _jz_jet[34][_jz_k-_jz_l]);
			     AssignJetToJet(stmp2, stmp);
			     AddJetJetA(stmp, stmp2, stmp1);
			 }
			 AssignJetToJet(_sjz_jet[29][_jz_k], stmp);
		 }
		 /* mult: v_103=(c_099*v_102) */
		 MultiplyMyFloatA(_jz_jet[36][_jz_k], _jz_cvars[13], _jz_jet[33][_jz_k]);
		 /* mult: v_106=(v_023*v_103) */
		 { /* multiplication */
			 static MY_FLOAT tmp1, tmp2, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp)
			 static MY_JET stmp1, stmp2, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp)
			 if(_jz_initialized==0) {
			   InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp);
			   InitJet(stmp1);InitJet(stmp2); InitJet(stmp);
			   }
			 AssignFloatToJet(stmp, _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<=_jz_k; _jz_l++) {
			     MultiplyJetFloatA(stmp1, _sjz_jet[1][_jz_l], _jz_jet[36][_jz_k-_jz_l]);
			     AssignJetToJet(stmp2, stmp);
			     AddJetJetA(stmp, stmp2, stmp1);
			 }
			 AssignJetToJet(_sjz_jet[30][_jz_k], stmp);
		 }
		 /* plus: v_107=(v_105+v_106) */
		 AddJetJetA(_sjz_jet[31][_jz_k], _sjz_jet[29][_jz_k],_sjz_jet[30][_jz_k]);
		 /* mult: v_108=(i_045*v_107) */
		 MultiplyFloatJetA(_sjz_jet[32][_jz_k], MakeMyFloatB(_jz_uvar1,(double)_jz_ivars[1]), _sjz_jet[31][_jz_k]);
		 /* minus: v_109=(v_075-v_108) */
		 SubtractJetJetA(_sjz_jet[33][_jz_k], _sjz_jet[12][_jz_k],_sjz_jet[32][_jz_k]);
		 /* plus: v_110=(c_068+v_109) */
		 AssignJetToJet(_sjz_jet[34][_jz_k], _sjz_jet[33][_jz_k]);
		 /* exponentiation: v_113=(v_110^c_082) */
		 { /* exponentiation */
				 /* expr^(-3/2)/ */ 
			 int  ppk=(-3)*_jz_k, qqk=(2)*_jz_k, pq=-1;
			 static MY_FLOAT tmp1, tmp2, tmp3, tmpC, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp3, tmpC, tmp)
			 static MY_JET stmp1, stmp2, stmp3, stmpC, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp3, stmpC, stmp)
			 if(_jz_initialized==0) {
			  InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp3);
			  InitMyFloat(tmpC);InitMyFloat(tmp);
				  InitJet(stmp1);InitJet(stmp2);InitJet(stmp3);InitJet(stmpC);InitJet(stmp);
			 }
			 AssignFloatToJet(stmp,  _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<_jz_k; _jz_l++) {
			     MakeMyFloatA(tmpC, ppk);
			     AssignFloatToJet(stmpC, tmpC);
			     ppk -= pq  ;
			     MultiplyJetJetA(stmp1, _sjz_jet[35][_jz_l],_sjz_jet[34][_jz_k-_jz_l]);
			     MultiplyJetJetA(stmp2, stmpC, stmp1);
			     AddJetJetA(stmp1,  stmp, stmp2);
			     AssignJetToJet(stmp,  stmp1);
			 }
			 MakeMyFloatA(tmp3,qqk);
			 AssignFloatToJet(stmp3,tmp3);
			 MultiplyJetJetA(stmp1, _sjz_jet[34][0], stmp3);
			 DivideJetJetA(_sjz_jet[35][_jz_k], stmp, stmp1);
		}
		 /* mult: v_124=(c_033*v_113) */
		 MultiplyFloatJetA(_sjz_jet[36][_jz_k], _jz_cvars[9], _sjz_jet[35][_jz_k]);
		 /* minus: v_125=(v_022-v_098) */
		 SubtractJetFloatA(_sjz_jet[37][_jz_k], _sjz_jet[0][_jz_k],_jz_jet[34][_jz_k]);
		 /* mult: v_126=(v_124*v_125) */
		 { /* multiplication */
			 static MY_FLOAT tmp1, tmp2, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp)
			 static MY_JET stmp1, stmp2, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp)
			 if(_jz_initialized==0) {
			   InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp);
			   InitJet(stmp1);InitJet(stmp2); InitJet(stmp);
			   }
			 AssignFloatToJet(stmp, _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<=_jz_k; _jz_l++) {
			     MultiplyJetJetA(stmp1, _sjz_jet[36][_jz_l], _sjz_jet[37][_jz_k-_jz_l]);
			     AssignJetToJet(stmp2, stmp);
			     AddJetJetA(stmp, stmp2, stmp1);
			 }
			 AssignJetToJet(_sjz_jet[38][_jz_k], stmp);
		 }
		 /* minus: v_127=(v_123-v_126) */
		 SubtractJetJetA(_sjz_jet[39][_jz_k], _sjz_jet[28][_jz_k],_sjz_jet[38][_jz_k]);
		 /* mult: v_128=(c_070*v_098) */
		 MultiplyMyFloatA(_jz_jet[47][_jz_k], _jz_cvars[15], _jz_jet[34][_jz_k]);
		 /* minus: v_129=(v_127-v_128) */
		 SubtractJetFloatA(_sjz_jet[40][_jz_k], _sjz_jet[39][_jz_k],_jz_jet[47][_jz_k]);
		 /* negation: v_130=(-v_025) */
		 NegateJetA(_sjz_jet[41][_jz_k], _sjz_jet[3][_jz_k]);
		 /* plus: v_133=(v_116+v_120) */
		 AddJetJetA(_sjz_jet[42][_jz_k], _sjz_jet[17][_jz_k],_sjz_jet[25][_jz_k]);
		 /* mult: v_134=(v_023*v_133) */
		 { /* multiplication */
			 static MY_FLOAT tmp1, tmp2, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp)
			 static MY_JET stmp1, stmp2, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp)
			 if(_jz_initialized==0) {
			   InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp);
			   InitJet(stmp1);InitJet(stmp2); InitJet(stmp);
			   }
			 AssignFloatToJet(stmp, _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<=_jz_k; _jz_l++) {
			     MultiplyJetJetA(stmp1, _sjz_jet[1][_jz_l], _sjz_jet[42][_jz_k-_jz_l]);
			     AssignJetToJet(stmp2, stmp);
			     AddJetJetA(stmp, stmp2, stmp1);
			 }
			 AssignJetToJet(_sjz_jet[43][_jz_k], stmp);
		 }
		 /* minus: v_135=(v_130-v_134) */
		 SubtractJetJetA(_sjz_jet[44][_jz_k], _sjz_jet[41][_jz_k],_sjz_jet[43][_jz_k]);
		 /* minus: v_137=(v_023-v_103) */
		 SubtractJetFloatA(_sjz_jet[45][_jz_k], _sjz_jet[1][_jz_k],_jz_jet[36][_jz_k]);
		 /* mult: v_138=(v_124*v_137) */
		 { /* multiplication */
			 static MY_FLOAT tmp1, tmp2, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp)
			 static MY_JET stmp1, stmp2, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp)
			 if(_jz_initialized==0) {
			   InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp);
			   InitJet(stmp1);InitJet(stmp2); InitJet(stmp);
			   }
			 AssignFloatToJet(stmp, _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<=_jz_k; _jz_l++) {
			     MultiplyJetJetA(stmp1, _sjz_jet[36][_jz_l], _sjz_jet[45][_jz_k-_jz_l]);
			     AssignJetToJet(stmp2, stmp);
			     AddJetJetA(stmp, stmp2, stmp1);
			 }
			 AssignJetToJet(_sjz_jet[46][_jz_k], stmp);
		 }
		 /* minus: v_139=(v_135-v_138) */
		 SubtractJetJetA(_sjz_jet[47][_jz_k], _sjz_jet[44][_jz_k],_sjz_jet[46][_jz_k]);
		 /* mult: v_140=(c_070*v_103) */
		 MultiplyMyFloatA(_jz_jet[56][_jz_k], _jz_cvars[15], _jz_jet[36][_jz_k]);
		 /* minus: v_141=(v_139-v_140) */
		 SubtractJetFloatA(_sjz_jet[48][_jz_k], _sjz_jet[47][_jz_k],_jz_jet[56][_jz_k]);
		 /* plus: v_146=(v_124+v_133) */
		 AddJetJetA(_sjz_jet[49][_jz_k], _sjz_jet[36][_jz_k],_sjz_jet[42][_jz_k]);
		 /* negation: v_147=(-v_146) */
		 NegateJetA(_sjz_jet[50][_jz_k], _sjz_jet[49][_jz_k]);
		 /* mult: v_148=(v_024*v_147) */
		 { /* multiplication */
			 static MY_FLOAT tmp1, tmp2, tmp;
			 #pragma omp threadprivate(tmp1, tmp2, tmp)
			 static MY_JET stmp1, stmp2, stmp;
			 #pragma omp threadprivate(stmp1, stmp2, stmp)
			 if(_jz_initialized==0) {
			   InitMyFloat(tmp1);InitMyFloat(tmp2); InitMyFloat(tmp);
			   InitJet(stmp1);InitJet(stmp2); InitJet(stmp);
			   }
			 AssignFloatToJet(stmp, _jz_MyFloatZERO);
			 for(_jz_l=0; _jz_l<=_jz_k; _jz_l++) {
			     MultiplyJetJetA(stmp1, _sjz_jet[2][_jz_l], _sjz_jet[50][_jz_k-_jz_l]);
			     AssignJetToJet(stmp2, stmp);
			     AddJetJetA(stmp, stmp2, stmp1);
			 }
			 AssignJetToJet(_sjz_jet[51][_jz_k], stmp);
		 }
		 /* derivative of state variables */
		 _jz_m = _jz_k+1;
		 /* state variable 0: */
		 DivideJetFloatA(_sjz_jet[0][_jz_m], _sjz_jet[6][_jz_k], _jz_theNs[_jz_m]);
		 AssignJetToFloat(_jz_jet[0][_jz_m], _sjz_jet[0][_jz_m]);
		 /* state variable 1: */
		 DivideJetFloatA(_sjz_jet[1][_jz_m], _sjz_jet[7][_jz_k], _jz_theNs[_jz_m]);
		 AssignJetToFloat(_jz_jet[1][_jz_m], _sjz_jet[1][_jz_m]);
		 /* state variable 2: */
		 DivideJetFloatA(_sjz_jet[2][_jz_m], _sjz_jet[5][_jz_k], _jz_theNs[_jz_m]);
		 AssignJetToFloat(_jz_jet[2][_jz_m], _sjz_jet[2][_jz_m]);
		 /* state variable 3: */
		 DivideJetFloatA(_sjz_jet[3][_jz_m], _sjz_jet[40][_jz_k], _jz_theNs[_jz_m]);
		 AssignJetToFloat(_jz_jet[3][_jz_m], _sjz_jet[3][_jz_m]);
		 /* state variable 4: */
		 DivideJetFloatA(_sjz_jet[4][_jz_m], _sjz_jet[48][_jz_k], _jz_theNs[_jz_m]);
		 AssignJetToFloat(_jz_jet[4][_jz_m], _sjz_jet[4][_jz_m]);
		 /* state variable 5: */
		 DivideJetFloatA(_sjz_jet[5][_jz_m], _sjz_jet[51][_jz_k], _jz_theNs[_jz_m]);
		 AssignJetToFloat(_jz_jet[5][_jz_m], _sjz_jet[5][_jz_m]);
		 _jz_initialized=1;
	 }
    _jz_lastOrder = order;
    _jz_ginitialized=1;
    if (sOut) {
     *sOut = _sjz_jet;
    }
    return(_jz_jet);
}

MY_FLOAT **taylor_coefficients_autoA(MY_FLOAT t, MY_FLOAT *x, int order, int rflag)
{
    return(taylor_coefficients_auto_A(t,x,order,rflag, NULL, NULL));
}

MY_FLOAT **taylor_coefficients_auto(MY_FLOAT t, MY_FLOAT *x, int order)
{
    return(taylor_coefficients_autoA(t,x,order,0));
}

#ifndef _JET_IO_HELPERS_
#define _JET_IO_HELPERS_


static const char *ode_variable_names[]={ "x", "y", "z", "px", "py", "pz", "t", NULL };

static const char *jet_variable_monomials[]={

"s1","s2","s3","s4","s5","s6",

NULL

};

#if _MAX_SIZE_OF_JET_VAR_ > 1

#include <stdio.h>
#include <ctype.h>
#include <string.h>

/*
 *  Jet IO Helpers.  These helpers assumes the jet libraries
 *  order the monomials using the lexicographical order. I.e, a
 *  jet is repesent as
 *    a0 + a1 s_1 + a2 s_2 + a3 s_3 + a4 s1^2 + a5 s1 s2 + a6 s1 s3 + a7 s2^2 + a8 s2 s3 + a9 s3^2 ...
 */

static char *get_next_number(const char *s, int *j, char *buf) {
  const char *p=s + *j;
  int i=0, k=0;
  while(p && *p && (!isdigit(*p)) && *p != '.' && *p != '-') {    k++; p++;  }
  while(p && *p && (isdigit(*p) || *p == '.' || *p == '-')) {  
    buf[i++] = *p++; k++;
  }
  buf[i++] = '\0';
  *j = *j+k;
  return buf;
}
static char *get_next_number_stdin(char *buf) {
  int i=0; char p = getc(stdin);
  while(p && (!isdigit(p)) && p != '.' && p != '-') { p = getc(stdin);  }
  while(p && (isdigit(p) || p == '.' || p == '-')) { buf[i++] = p; p = getc(stdin);}
  buf[i++] = '\0'; return buf;
}


static int taylor_gen_jetvar_prompt(int i, char *buf) {
  /* extern char *ode_variable_names[], *jet_variable_monomials[];  */
  
  const char *me = ode_variable_names[i];
  char tmp[128]; 
  int j;

  sprintf(buf, "%s", me);
  j = 0;
  while(jet_variable_monomials[j] != NULL) {
    sprintf(tmp, ",%s", jet_variable_monomials[j]);
    (void)strcat(buf, tmp);
    j++;
  }
  return j+1;
}

/* 
 *  create jet var from an array of doubles
 *  Parms:  a, JET var
 *          values, an array of doubles assign to jet
 *                  caller needs to make sure there are  
 *                  enough number in values
 */

int taylor_make_jet(MY_JET a, MY_COEF *mycoefs, MY_FLOAT *myfloats, double *values) {
  int i;
  MY_COEF *dtmp = (MY_COEF *) malloc((_MAX_SIZE_OF_JET_VAR_) * sizeof(MY_COEF));
  if (dtmp == NULL) {
    fprintf(stderr, "Unable to allocate %d bytes.", (int) ( (_MAX_SIZE_OF_JET_VAR_) * sizeof(MY_COEF)));
    fflush(stderr); exit(9);
  }
  if (mycoefs != NULL) {
    for (i = 0; i < _MAX_SIZE_OF_JET_VAR_; i++) {
      mycoef_init(dtmp[i]);
      mycoef_set(dtmp[i],mycoefs[i]);
    }
  } else if (myfloats != NULL) {
    for (i = 0; i < _MAX_SIZE_OF_JET_VAR_; i++) {
      mycoef_init(dtmp[i]);
      mycoef_set_myfloat(dtmp[i],myfloats[i]);
    }
  } else if(values != NULL) {
    for (i = 0; i < _MAX_SIZE_OF_JET_VAR_; i++) {
      mycoef_init(dtmp[i]);
      mycoef_set_d(dtmp[i],values[i]);
    }
  }
  // The monomials solicited here are in lexical order. We need to
  // make sure our assigment macro/function are using the matching
  // order
  MY_JET_FUN(set_coef_array)(a,dtmp);
  for(i = 0; i < _MAX_SIZE_OF_JET_VAR_; i++) {
    mycoef_clean(dtmp[i]);
  }
  (void)free(dtmp);
  return 0;
}

/*
 *  Make an identity jet. If values is give, set the value of the
 *  state variables. Otherwise, leave the state variable alone.
 */

int taylor_make_identity_jets(MY_JET *inOut, MY_COEF *mycoefs, MY_FLOAT *myfloats, double *values) {
  int i,j, k;

  k = _NUMBER_OF_JET_VARS_ > _NUMBER_OF_MAX_SYMBOLS_ ? _NUMBER_OF_MAX_SYMBOLS_ : _NUMBER_OF_JET_VARS_;
  
  for(i = 0; i < k; i++) {
    for (j = 0; j < _MAX_SIZE_OF_JET_VAR_; j++) {
      if (j == 0 ) {
        if (mycoefs != NULL) {
          mycoef_set(MY_JET_DATA((inOut[i]),0),mycoefs[i]);
        } else if(myfloats != NULL) {
          mycoef_set_myfloat(MY_JET_DATA((inOut[i]),0),myfloats[i]);
	} else if( values != NULL) {
          mycoef_set_d(MY_JET_DATA((inOut[i]),0),values[i]);
	}
      } else {
	if(i == j-1) { // offset by 1.
          mycoef_set_si( MY_JET_DATA((inOut[i]),j),1);
	} else {
          mycoef_set_si( MY_JET_DATA((inOut[i]),j),0);
	}
      }
    }
  }
  for (i = k; i < _NUMBER_OF_STATE_VARS_; i++) {
    for (j = 0; j < _MAX_SIZE_OF_JET_VAR_; j++) {
      if (j == 0) {
        if (mycoefs != NULL) {
           mycoef_set(MY_JET_DATA((inOut[i]),0),mycoefs[i]);
        } else if (myfloats != NULL) {
          mycoef_set_myfloat(MY_JET_DATA((inOut[i]),0),myfloats[i]);
        } else if (values != NULL) {	
          mycoef_set_d(MY_JET_DATA((inOut[i]),0),values[i]);
        } else {
          mycoef_set_si(MY_JET_DATA((inOut[i]),0),0);
        }
      } else {
        mycoef_set_si( MY_JET_DATA((inOut[i]),j),0);
      }
    }
  }
  return 0;
}

/*
 *   make an unit jet
 *     jet = v + s_idx
 *   idx is 0 based, s0, s1, s2 etc. 
 */
int taylor_make_unit_jet(MY_JET a, int idx, MY_COEF *mycoef, MY_FLOAT *myfloat, double *value) {
  for (int j = 0; j < _MAX_SIZE_OF_JET_VAR_; j++) {
    if (j == 0) {
      if (mycoef != NULL) {
        mycoef_set(MY_JET_DATA((a),0),*mycoef);
      } if (myfloat != NULL) {
        mycoef_set_myfloat(MY_JET_DATA((a),0),*myfloat);
      } else if(value != NULL) {
        mycoef_set_d(MY_JET_DATA((a),0),*value);
      }
    } else {
      if (j == idx+1) {
        mycoef_set_si(MY_JET_DATA((a),j),1);
      } else {
        mycoef_set_si(MY_JET_DATA((a),j),0);
      }
    }
  }
  return 0;
}


/*
 *  Set the value of jet using an array of MY_FLOATs.
 *  optionally set the state variable. 
 */
int taylor_set_jet(MY_JET a, MY_COEF *mycoefs, MY_FLOAT *myfloats, double *values, int include_state) {
  int j, offset = 1;
  if (include_state) offset = 0;
  else {mycoef_set_si( MY_JET_DATA((a),0),0);}
  
  if (mycoefs != NULL) {
    for(j = offset; j < _MAX_SIZE_OF_JET_VAR_; j++) {
      mycoef_set( MY_JET_DATA((a),j),mycoefs[j-offset]);
    }
  } else if (myfloats != NULL) {
    for(j = offset; j < _MAX_SIZE_OF_JET_VAR_; j++) {
      mycoef_set_myfloat( MY_JET_DATA((a),j),myfloats[j-offset]);
    }
  } else if (values != NULL) {
    for(j = offset; j < _MAX_SIZE_OF_JET_VAR_; j++) {
      mycoef_set_d( MY_JET_DATA((a),j),values[j-offset]);
    }
  }
  return 0;
}

/*
 *  Output a jet to an array of MY_FLOATs, optionally include
 *  the state variable.
 */
MY_COEF *taylor_convert_jet_to_array(MY_JET a, int include_state) {
  int i,offset = 1;
  if (include_state) offset = 0;
  
  static MY_COEF *dtmp = NULL;
#pragma omp threadprivate(dtmp)
  
  if(dtmp == NULL) {
    dtmp = (MY_COEF *) malloc((_MAX_SIZE_OF_JET_VAR_) * sizeof(MY_COEF));
    if(dtmp == NULL) {
      fprintf(stderr, "Unable to allocate %d bytes.", (int) ( (_MAX_SIZE_OF_JET_VAR_) * sizeof(MY_COEF)));
      fflush(stderr); exit(9);
    }
    for(i = 0; i < _MAX_SIZE_OF_JET_VAR_; i++) {
      mycoef_init(dtmp[i]);
      mycoef_set_si(dtmp[i], 0);
    }
  }
  for(i = offset; i < _MAX_SIZE_OF_JET_VAR_; i++) {
    mycoef_set(dtmp[i-offset],  MY_JET_DATA((a),i));
  }
  return dtmp;
}


/*
 *  taylor_input_jet: input jet from stdin,  prompt with list of monomials in jet var
 *
 *  Parms:  a, JET var
 *          idx, index of a in Jet Array. The order
 *             of the Jet Array is affixed with the
 *             order of LHS of ODEs 
 *          values, an array of doubles assign to jet
 *                  caller needs to make sure there are  
 *                  enough number in values
 */

int taylor_input_jet_from_stdin(MY_JET a, int idx) {
  /* extern char *ode_variable_names[]; */
  char buf[2048];
  int i, count, nbytes;

  MY_FLOAT *dtmp = (MY_FLOAT *)malloc((_MAX_SIZE_OF_JET_VAR_) * sizeof(MY_FLOAT));
  if(dtmp == NULL) {
    fprintf(stderr, "Unable to allocate %d bytes.", (int) ( (_MAX_SIZE_OF_JET_VAR_) * sizeof(MY_FLOAT)));
    exit(9);
  }
  for(i = 0; i < _MAX_SIZE_OF_JET_VAR_; i++) {
    InitMyFloat(dtmp[i]);
  }
  
  bzero(buf, 2048);
  count = taylor_gen_jetvar_prompt(idx, buf);

  fprintf(stderr, "Enter values for JET Var %s: %s \n", ode_variable_names[idx], buf);
  buf[0] =0;
  for(i = 0; i < _MAX_SIZE_OF_JET_VAR_; i++) {
    char *q = get_next_number_stdin(buf);
    double f = atof(q);
    MakeMyFloatC(dtmp[i], buf, f);    
  }
  
  taylor_make_jet(a, NULL, dtmp, NULL);
  
  for(i = 0; i < _MAX_SIZE_OF_JET_VAR_; i++) {
    ClearMyFloat(dtmp[i]);
  }
  (void) free(dtmp);

  return 0;
}

int taylor_input_jet_from_string(MY_JET a, const char *str) {
  static char buf[256];
  static MY_FLOAT *dtmp = NULL;  
#pragma omp threadprivate(buf,dtmp)
  int i, j=0;
  if(dtmp == NULL) {
    dtmp = (MY_FLOAT *)malloc((_MAX_SIZE_OF_JET_VAR_) * sizeof(MY_FLOAT));
    if(dtmp == NULL) {
      fprintf(stderr, "Unable to allocate %d bytes.", (int) ( (_MAX_SIZE_OF_JET_VAR_) * sizeof(MY_FLOAT)));
      exit(9);
    }
    for(i = 0; i < _MAX_SIZE_OF_JET_VAR_; i++) {
      InitMyFloat(dtmp[i]);
      MakeMyFloatA(dtmp[i], 0.0);
    }
  }
  for(i=0; i< _MAX_SIZE_OF_JET_VAR_; i++) {
    get_next_number(str, &j, buf);
    double f=atof(buf);
    MakeMyFloatC(dtmp[i], buf, f);
  }

  taylor_make_jet(a, NULL, dtmp, NULL);
  return 0;
}

int taylor_output_jet(FILE *file, const char *fmt, MY_JET a) {
  OutputJet2File(file,fmt,a);
}

void taylor_initialize_jet_library2(int nsymbs, int degree) {
  InitUpJet2(nsymbs, degree);
}
void taylor_initialize_jet_library(void) {
  InitUpJet();
}

void taylor_initialize_jet_variable(MY_JET *jet) {
  InitJet(*jet);
}

void taylor_clear_jet_variable(MY_JET *jet) {
  ClearJet(*jet);
}
void taylor_clear_up_jet_library(void) {
  ClearUpJet();
}

int taylor_set_jet_variable_degree(int deg) {
  return SetJetVarDegree(deg);
}
int taylor_set_jet_variable_number_of_symbols(int nsyms) {
  return SetJetNumSymbols(nsyms);
}

const char **taylor_get_variable_names() {
  return ode_variable_names;
}

const char **taylor_get_jet_monomials() {
  return jet_variable_monomials;
}
#endif



#endif /* _JET_IO_HELPERS_ */

